#![allow(clippy::missing_panics_doc)]
use std::io::BufReader;

use super::IdentifiedPeptideSource;

use super::{csv::parse_csv_raw, msfragger, IdentifiedPeptide, MSFraggerData};

#[test]
fn msfragger_v21() {
    let reader = BufReader::new(DATA_V21.as_bytes());
    let lines = parse_csv_raw(reader, b'\t', None).unwrap();
    for line in lines.map(std::result::Result::unwrap) {
        println!("{line}");
        let _read: IdentifiedPeptide = MSFraggerData::parse_specific(&line, &msfragger::V21, None)
            .unwrap()
            .into();
    }
}

#[test]
fn msfragger_v22() {
    let reader = BufReader::new(DATA_V22.as_bytes());
    let lines = parse_csv_raw(reader, b'\t', None).unwrap();
    for line in lines.map(std::result::Result::unwrap) {
        println!("{line}");
        let _read: IdentifiedPeptide = MSFraggerData::parse_specific(&line, &msfragger::V22, None)
            .unwrap()
            .into();
    }
}

#[test]
fn msfragger_v21_manual() {
    let reader = BufReader::new(DATA_V21_MANUAL.as_bytes());
    let lines = parse_csv_raw(reader, b'\t', None).unwrap();
    for line in lines.map(std::result::Result::unwrap) {
        println!("{line}");
        let _read: IdentifiedPeptide = MSFraggerData::parse_specific(&line, &msfragger::V21, None)
            .unwrap()
            .into();
    }
}

#[test]
fn msfragger_detect() {
    let reader = BufReader::new(DATA_V21.as_bytes());
    let lines = parse_csv_raw(reader, b'\t', None).unwrap();
    for line in lines.map(std::result::Result::unwrap) {
        println!("{line}");
        let result = MSFraggerData::parse(&line, None).unwrap();
        let _read: IdentifiedPeptide = result.0.into();
        assert_eq!(result.1, &msfragger::V21);
    }
}

const DATA_V21_MANUAL: &str = r"Spectrum	Spectrum File	Peptide	Modified Peptide	Extended Peptide	Prev AA	Next AA	Peptide Length	Charge	Retention	Observed Mass	Calibrated Observed Mass	Observed M/Z	Calibrated Observed M/Z	Calculated Peptide Mass	Calculated M/Z	Delta Mass	Expectation	Hyperscore	Nextscore	PeptideProphet Probability	Number of Enzymatic Termini	Number of Missed Cleavages	Protein Start	Protein End	Intensity	Assigned Modifications	Observed Modifications	Purity	Is Unique	Protein	Protein ID	Entry Name	Gene	Protein Description	Mapped Genes	Mapped Proteins	condition	group
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1A_Alk14_R1.21346.21346.2	D:\06-June\6579035\SS25\MSFragger_4-24\1_alk14_1\interact.pep.xml	GAQLSGGR	n[621]GAQLSGGR	.GAQLSGGR.GAPEPAQT	M	G	8	2	1811.7999	1364.8169	1364.8121	683.4157	683.4133	1364.814	683.4143	-0.0018	1.449549e-05	24.446	10.854	1	2	0	2	9	478745568	N-term(DB14 (N-term))		0	true	sp|A0A0U1RRL7|MMPOS_HUMAN	A0A0U1RRL7	MMPOS_HUMAN	MMP24OS	Protein MMP24OS			1_alk14_1	1_alk14
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1B_Alk14_R2.20911.20911.2	D:\06-June\6579035\SS25\MSFragger_4-24\1_alk14_2\interact.pep.xml	GAQLSGGR	n[621]GAQLSGGR	.GAQLSGGR.GAPEPAQT	M	G	8	2	1812.5955	1364.8169	1364.8116	683.4157	683.4131	1364.814	683.4143	-0.0023	1.071478e-05	24.441	10.843	1	2	0	2	9	405120480	N-term(DB14 (N-term))		0	true	sp|A0A0U1RRL7|MMPOS_HUMAN	A0A0U1RRL7	MMPOS_HUMAN	MMP24OS	Protein MMP24OS			1_alk14_2	1_alk14
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1C_Alk14_R3.20941.20941.2	D:\06-June\6579035\SS25\MSFragger_4-24\1_alk14_3\interact.pep.xml	GAQLSGGR	n[621]GAQLSGGR	.GAQLSGGR.GAPEPAQT	M	G	8	2	1815.257	1364.8164	1364.8118	683.4155	683.4132	1364.814	683.4143	-0.0022	0.0001124486	22.515	11.357	1	2	0	2	9	336166400	N-term(DB14 (N-term))		0	true	sp|A0A0U1RRL7|MMPOS_HUMAN	A0A0U1RRL7	MMPOS_HUMAN	MMP24OS	Protein MMP24OS			1_alk14_3	1_alk14
20240621_EX2_UM2_6579035_SA_EXT00_SS25_2A_Alk18_R1.21240.21240.2	D:\06-June\6579035\SS25\MSFragger_4-24\2_alk18_1\interact.pep.xml	GAQLSGGR	n[621]GAQLSGGR	.GAQLSGGR.GAPEPAQT	M	G	8	2	1812.562	1364.8175	1364.8137	683.416	683.4141	1364.814	683.4143	-2e-04	2.061197e-06	24.538	12.56	1	2	0	2	9	94464872	N-term(DB14 (N-term))		0	true	sp|A0A0U1RRL7|MMPOS_HUMAN	A0A0U1RRL7	MMPOS_HUMAN	MMP24OS	Protein MMP24OS			2_alk18_1	2_alk18
20240621_EX2_UM2_6579035_SA_EXT00_SS25_2B_Alk18_R2.20967.20967.2	D:\06-June\6579035\SS25\MSFragger_4-24\2_alk18_2\interact.pep.xml	GAQLSGGR	n[621]GAQLSGGR	.GAQLSGGR.GAPEPAQT	M	G	8	2	1808.432	1364.8167	1364.8138	683.4156	683.4142	1364.814	683.4143	-1e-04	8.001148e-05	20.976	10.621	1	2	0	2	9	128396368	N-term(DB14 (N-term))		0	true	sp|A0A0U1RRL7|MMPOS_HUMAN	A0A0U1RRL7	MMPOS_HUMAN	MMP24OS	Protein MMP24OS			2_alk18_2	2_alk18
20240621_EX2_UM2_6579035_SA_EXT00_SS25_2C_Alk18_R3.20937.20937.2	D:\06-June\6579035\SS25\MSFragger_4-24\2_alk18_3\interact.pep.xml	GAQLSGGR	n[621]GAQLSGGR	.GAQLSGGR.GAPEPAQT	M	G	8	2	1808.6516	1364.8202	1364.8115	683.4174	683.413	1364.814	683.4143	-0.0024	6.004605e-06	22.601	10.935	1	2	0	2	9	113564416	N-term(DB14 (N-term))		0	true	sp|A0A0U1RRL7|MMPOS_HUMAN	A0A0U1RRL7	MMPOS_HUMAN	MMP24OS	Protein MMP24OS			2_alk18_3	2_alk18
20240621_EX2_UM2_6579035_SA_EXT00_SS25_4A_Alk16_R1.21260.21260.2	D:\06-June\6579035\SS25\MSFragger_4-24\4_alk16_1\interact.pep.xml	GAQLSGGR	n[621]GAQLSGGR	.GAQLSGGR.GAPEPAQT	M	G	8	2	1813.5679	1364.8176	1364.8124	683.4161	683.4135	1364.814	683.4143	-0.0015	2.260152e-05	22.606	10.858	1	2	0	2	9	130142952	N-term(DB14 (N-term))		0	true	sp|A0A0U1RRL7|MMPOS_HUMAN	A0A0U1RRL7	MMPOS_HUMAN	MMP24OS	Protein MMP24OS			4_alk16_1	4_alk16
20240621_EX2_UM2_6579035_SA_EXT00_SS25_4B_Alk16_PalmB_R1.20857.20857.2	D:\06-June\6579035\SS25\MSFragger_4-24\4_alk16_PalmB_1\interact.pep.xml	GAQLSGGR	n[621]GAQLSGGR	.GAQLSGGR.GAPEPAQT	M	G	8	2	1810.3729	1364.8219	1364.8137	683.4182	683.4141	1364.814	683.4143	-2e-04	0.0002379872	22.598	12.345	0.9999	2	0	2	9	190353824	N-term(DB14 (N-term))		0	true	sp|A0A0U1RRL7|MMPOS_HUMAN	A0A0U1RRL7	MMPOS_HUMAN	MMP24OS	Protein MMP24OS			4_alk16_PalmB_1	4_alk16_PalmB
20240621_EX2_UM2_6579035_SA_EXT00_SS25_5A_Alk16_Pal_R1.20883.20883.2	D:\06-June\6579035\SS25\MSFragger_4-24\5_alk16_Pal_1\interact.pep.xml	GAQLSGGR	n[621]GAQLSGGR	.GAQLSGGR.GAPEPAQT	M	G	8	2	1813.8567	1364.8212	1364.8138	683.4179	683.4142	1364.814	683.4143	-1e-04	0.0004045984	24.462	12.404	0.9992	2	0	2	9	154401744	N-term(DB14 (N-term))		0	true	sp|A0A0U1RRL7|MMPOS_HUMAN	A0A0U1RRL7	MMPOS_HUMAN	MMP24OS	Protein MMP24OS			5_alk16_Pal_1	5_alk16_Pal
20240621_EX2_UM2_6579035_SA_EXT00_SS25_5B_Alk16_Pal_PalmB_R1.20819.20819.2	D:\06-June\6579035\SS25\MSFragger_4-24\5_alk16_Pal_PalmB_1\interact.pep.xml	GAQLSGGR	n[621]GAQLSGGR	.GAQLSGGR.GAPEPAQT	M	G	8	2	1814.5015	1364.8198	1364.8131	683.4172	683.4138	1364.814	683.4143	-8e-04	7.709754e-05	22.576	10.563	0.9999	2	0	2	9	104913152	N-term(DB14 (N-term))		0	true	sp|A0A0U1RRL7|MMPOS_HUMAN	A0A0U1RRL7	MMPOS_HUMAN	MMP24OS	Protein MMP24OS			5_alk16_Pal_PalmB_1	5_alk16_Pal_PalmB
20240621_EX2_UM2_6579035_SA_EXT00_SS25_6A_Alk16_R1.21150.21150.2	D:\06-June\6579035\SS25\MSFragger_4-24\6_alk16_1\interact.pep.xml	GAQLSGGR	n[621]GAQLSGGR	.GAQLSGGR.GAPEPAQT	M	G	8	2	1817.2166	1364.8165	1364.8123	683.4155	683.4134	1364.814	683.4143	-0.0017	3.403439e-05	24.466	12.473	1	2	0	2	9	132069376	N-term(DB14 (N-term))		0	true	sp|A0A0U1RRL7|MMPOS_HUMAN	A0A0U1RRL7	MMPOS_HUMAN	MMP24OS	Protein MMP24OS			6_alk16_1	6_alk16
20240621_EX2_UM2_6579035_SA_EXT00_SS25_6B_Alk16_R2.20804.20804.2	D:\06-June\6579035\SS25\MSFragger_4-24\6_alk16_2\interact.pep.xml	GAQLSGGR	n[621]GAQLSGGR	.GAQLSGGR.GAPEPAQT	M	G	8	2	1815.9492	1364.8158	1364.8124	683.4152	683.4135	1364.814	683.4143	-0.0015	8.502157e-06	24.42	10.801	1	2	0	2	9	134183824	N-term(DB14 (N-term))		0	true	sp|A0A0U1RRL7|MMPOS_HUMAN	A0A0U1RRL7	MMPOS_HUMAN	MMP24OS	Protein MMP24OS			6_alk16_2	6_alk16
20240621_EX2_UM2_6579035_SA_EXT00_SS25_6C_Alk16_R3.20829.20829.2	D:\06-June\6579035\SS25\MSFragger_4-24\6_alk16_3\interact.pep.xml	GAQLSGGR	n[621]GAQLSGGR	.GAQLSGGR.GAPEPAQT	M	G	8	2	1816.5289	1364.818	1364.8123	683.4163	683.4134	1364.814	683.4143	-0.0017	0.0001139548	22.578	10.563	0.9994	2	0	2	9	125611392	N-term(DB14 (N-term))		0	true	sp|A0A0U1RRL7|MMPOS_HUMAN	A0A0U1RRL7	MMPOS_HUMAN	MMP24OS	Protein MMP24OS			6_alk16_3	6_alk16
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1A_Alk14_R1.16011.16011.5	D:\06-June\6579035\SS25\MSFragger_4-24\1_alk14_1\interact.pep.xml	GSRVSREDFEWVYTDQPHADR	n[621]GSRVSREDFEWVYTDQPHADR	.GSRVSREDFEWVYTDQPHADR.RREIIAKY	M	R	21	5	1398.2484	3170.5984	3170.5918	635.127	635.1256	3169.5945	634.9262	0.9973	1.033e-11	32.408	11.852	1	2	2	2	22	9317484	N-term(DB14 (N-term))		0	true	sp|O15121|DEGS1_HUMAN	O15121	DEGS1_HUMAN	DEGS1	Sphingolipid delta(4)-desaturase DES1			1_alk14_1	1_alk14
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1A_Alk14_R1.16037.16037.4	D:\06-June\6579035\SS25\MSFragger_4-24\1_alk14_1\interact.pep.xml	GSRVSREDFEWVYTDQPHADR	n[621]GSRVSREDFEWVYTDQPHADR	.GSRVSREDFEWVYTDQPHADR.RREIIAKY	M	R	21	4	1400.2513	3169.6096	3169.6006	793.4097	793.4074	3169.5945	793.4059	0.0061	6.86234e-09	31.712	13.402	1	2	2	2	22	47059968	N-term(DB14 (N-term))		0	true	sp|O15121|DEGS1_HUMAN	O15121	DEGS1_HUMAN	DEGS1	Sphingolipid delta(4)-desaturase DES1			1_alk14_1	1_alk14
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1B_Alk14_R2.15625.15625.4	D:\06-June\6579035\SS25\MSFragger_4-24\1_alk14_2\interact.pep.xml	GSRVSREDFEWVYTDQPHADR	n[621]GSRVSREDFEWVYTDQPHADR	.GSRVSREDFEWVYTDQPHADR.RREIIAKY	M	R	21	4	1402.8964	3171.6147	3171.6138	793.911	793.9107	3169.5945	793.4059	2.0192	1.560578e-05	23.294	13.621	1	2	2	2	22	7783076	N-term(DB14 (N-term))		0	true	sp|O15121|DEGS1_HUMAN	O15121	DEGS1_HUMAN	DEGS1	Sphingolipid delta(4)-desaturase DES1			1_alk14_2	1_alk14
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1C_Alk14_R3.15633.15633.4	D:\06-June\6579035\SS25\MSFragger_4-24\1_alk14_3\interact.pep.xml	GSRVSREDFEWVYTDQPHADR	n[621]GSRVSREDFEWVYTDQPHADR	.GSRVSREDFEWVYTDQPHADR.RREIIAKY	M	R	21	4	1403.9133	3169.6055	3169.5989	793.4087	793.407	3169.5945	793.4059	0.0043	4.64e-12	38.268	14.712	1	2	2	2	22	33675408	N-term(DB14 (N-term))		0	true	sp|O15121|DEGS1_HUMAN	O15121	DEGS1_HUMAN	DEGS1	Sphingolipid delta(4)-desaturase DES1			1_alk14_3	1_alk14
20240621_EX2_UM2_6579035_SA_EXT00_SS25_4B_Alk16_PalmB_R1.15533.15533.4	D:\06-June\6579035\SS25\MSFragger_4-24\4_alk16_PalmB_1\interact.pep.xml	GSRVSREDFEWVYTDQPHADR	n[621]GSRVSREDFEWVYTDQPHADR	.GSRVSREDFEWVYTDQPHADR.RREIIAKY	M	R	21	4	1397.6398	3169.6094	3169.615	793.4096	793.411	3169.5945	793.4059	0.0205	0.0001729633	22.886	14.728	1	2	2	2	22	18261846	N-term(DB14 (N-term))		0	true	sp|O15121|DEGS1_HUMAN	O15121	DEGS1_HUMAN	DEGS1	Sphingolipid delta(4)-desaturase DES1			4_alk16_PalmB_1	4_alk16_PalmB
20240621_EX2_UM2_6579035_SA_EXT00_SS25_5A_Alk16_Pal_R1.15538.15538.4	D:\06-June\6579035\SS25\MSFragger_4-24\5_alk16_Pal_1\interact.pep.xml	GSRVSREDFEWVYTDQPHADR	n[621]GSRVSREDFEWVYTDQPHADR	.GSRVSREDFEWVYTDQPHADR.RREIIAKY	M	R	21	4	1399.581	3169.5972	3169.6016	793.4066	793.4077	3169.5945	793.4059	0.007	2.785583e-08	29.282	12.917	1	2	2	2	22	23077696	N-term(DB14 (N-term))		0	true	sp|O15121|DEGS1_HUMAN	O15121	DEGS1_HUMAN	DEGS1	Sphingolipid delta(4)-desaturase DES1			5_alk16_Pal_1	5_alk16_Pal
";

const DATA_V21: &str = r"Spectrum	Spectrum File	Peptide	Modified Peptide	Extended Peptide	Prev AA	Next AA	Peptide Length	Charge	Retention	Observed Mass	Calibrated Observed Mass	Observed M/Z	Calibrated Observed M/Z	Calculated Peptide Mass	Calculated M/Z	Delta Mass	Expectation	Hyperscore	Nextscore	PeptideProphet Probability	Number of Enzymatic Termini	Number of Missed Cleavages	Protein Start	Protein End	Intensity	Assigned Modifications	Observed Modifications	Purity	Is Unique	Protein	Protein ID	Entry Name	Gene	Protein Description	Mapped Genes	Mapped Proteins
20240206_EX1_UM3_6579035_SA_EXT00_SS16_pH7p5-single_res30k.03832.03832.3	D:\02-February\6579035\SS16\MSFragger3\4_res30k_1\interact.pep.xml	QVHPDTGISSK		VYVYKVIK.QVHPDTGISSK.AMGIMNSF	K	A	11	3	503.3970	1167.5969	1167.5906	390.2062	390.2041	1167.5884	390.2034	0.0022	0.00026471960000	21.3860	11.0140	0.9999	2	0	48	58	1.1243405E7			0.00	false	sp|O60814|H2B1K_HUMAN	O60814	H2B1K_HUMAN	H2BC12	Histone H2B type 1-K	H2BC1, H2BC11, H2BC12L, H2BC13, H2BC14, H2BC15, H2BC17, H2BC18, H2BC21, H2BC26, H2BC3, H2BC4, H2BC5, H2BC9	sp|P06899|H2B1J_HUMAN, sp|P23527|H2B1O_HUMAN, sp|P33778|H2B1B_HUMAN, sp|P57053|H2BFS_HUMAN, sp|P58876|H2B1D_HUMAN, sp|P62807|H2B1C_HUMAN, sp|Q16778|H2B2E_HUMAN, sp|Q5QNW6|H2B2F_HUMAN, sp|Q8N257|H2B3B_HUMAN, sp|Q93079|H2B1H_HUMAN, sp|Q96A08|H2B1A_HUMAN, sp|Q99877|H2B1N_HUMAN, sp|Q99879|H2B1M_HUMAN, sp|Q99880|H2B1L_HUMAN
20240206_EX1_UM3_6579035_SA_EXT00_SS16_pH7p5-single_res30k.03833.03833.4	D:\02-February\6579035\SS16\MSFragger3\4_res30k_1\interact.pep.xml	LAQHITYVHQHSR		PDRDNDIR.LAQHITYVHQHSR.QPPSQFEP	R	Q	13	4	503.4661	1588.8329	1588.8269	398.2155	398.2140	1588.8221	398.2128	0.0047	0.00001598673000	26.5640	11.3860	0.9924	2	0	533	545	3841888.2			0.00	true	sp|P33993|MCM7_HUMAN	P33993	MCM7_HUMAN	MCM7	DNA replication licensing factor MCM7		
20240206_EX1_UM3_6579035_SA_EXT00_SS16_pH7p5-single_res30k.03835.03835.3	D:\02-February\6579035\SS16\MSFragger3\4_res30k_1\interact.pep.xml	RVHPVSTMIK	RVHPVSTM[147]IK	ESIMKNIR.RVHPVSTMIK.GIYGIKDD	R	G	10	3	503.6042	1182.6621	1182.6564	395.2280	395.2261	1182.6542	395.2253	0.0022	0.05410656000000	15.5670	9.7440	0.9549	2	0	269	278	2613044.5	8M(15.9949)		0.00	true	sp|P00338|LDHA_HUMAN	P00338	LDHA_HUMAN	LDHA	L-lactate dehydrogenase A chain		
20240206_EX1_UM3_6579035_SA_EXT00_SS16_pH7p5-single_res30k.03836.03836.3	D:\02-February\6579035\SS16\MSFragger3\4_res30k_1\interact.pep.xml	YAAVHVHTNAAR		HGGVDAAR.YAAVHVHTNAAR.QPEIPTDP	R	Q	12	3	503.6732	1308.6769	1308.6758	437.2329	437.2325	1308.6686	437.2301	0.0072	0.00089430330000	22.0700	11.1290	0.9748	2	0	208	219	1126480.5			0.00	true	sp|P49593|PPM1F_HUMAN	P49593	PPM1F_HUMAN	PPM1F	Protein phosphatase 1F		
20240206_EX1_UM3_6579035_SA_EXT00_SS16_pH7p5-single_res30k.03839.03839.3	D:\02-February\6579035\SS16\MSFragger3\4_res30k_1\interact.pep.xml	YHTINGHNAEVR		VDKIVIQK.YHTINGHNAEVR.KAISRQEM	K	K	12	3	503.8802	1409.6904	1409.6837	470.9041	470.9018	1409.6799	470.9006	0.0037	0.00079434030000	20.3370	10.6400	0.9952	2	0	174	185	591109.75			0.00	true	sp|P22626|ROA2_HUMAN	P22626	ROA2_HUMAN	HNRNPA2B1	Heterogeneous nuclear ribonucleoproteins A2/B1		
20240206_EX1_UM3_6579035_SA_EXT00_SS16_pH7p5-single_res30k.03841.03841.2	D:\02-February\6579035\SS16\MSFragger3\4_res30k_1\interact.pep.xml	KGNYAER		GRVHRIIR.KGNYAER.VGAGAPVY	R	V	7	2	504.0823	836.4199	836.4175	419.2172	419.2160	836.4140	419.2143	0.0035	0.08560515000000	15.7700	10.2640	0.6368	2	0	37	43	601093.2			0.00	false	sp|Q8IUE6|H2A2B_HUMAN	Q8IUE6	H2A2B_HUMAN	H2AC21	Histone H2A type 2-B	H2AC1, H2AC11, H2AC12, H2AC14, H2AC18, H2AC20, H2AC6, H2AJ	sp|P0C0S8|H2A1_HUMAN, sp|Q16777|H2A2C_HUMAN, sp|Q6FI13|H2A2A_HUMAN, sp|Q93077|H2A1C_HUMAN, sp|Q96KK5|H2A1H_HUMAN, sp|Q96QV6|H2A1A_HUMAN, sp|Q99878|H2A1J_HUMAN, sp|Q9BTM1|H2AJ_HUMAN
20240206_EX1_UM3_6579035_SA_EXT00_SS16_pH7p5-single_res30k.03844.03844.4	D:\02-February\6579035\SS16\MSFragger3\4_res30k_1\interact.pep.xml	GATYGKPVHHGVNQLK		GRKRPVPK.GATYGKPVHHGVNQLK.FARSIQSV	K	F	16	4	504.2902	1704.9222	1704.9090	427.2378	427.2345	1704.9059	427.2338	0.0031	0.00446798800000	16.6860	11.8410	0.9751	2	1	78	93	2501933.0			0.00	true	sp|P61313|RL15_HUMAN	P61313	RL15_HUMAN	RPL15	Large ribosomal subunit protein eL15		
20240206_EX1_UM3_6579035_SA_EXT00_SS16_pH7p5-single_res30k.03845.03845.3	D:\02-February\6579035\SS16\MSFragger3\4_res30k_1\interact.pep.xml	TATPQQAQEVHEK		VWAIGTGK.TATPQQAQEVHEK.LRGWIKSN	K	L	13	3	504.3589	1465.7305	1465.7218	489.5841	489.5812	1465.7161	489.5793	0.0057	0.00000002028558	24.5800	11.2030	1.0000	2	0	176	188	369540.88			0.00	true	sp|P60174|TPIS_HUMAN	P60174	TPIS_HUMAN	TPI1	Triosephosphate isomerase		
20240206_EX1_UM3_6579035_SA_EXT00_SS16_pH7p5-single_res30k.03850.03850.3	D:\02-February\6579035\SS16\MSFragger3\4_res30k_1\interact.pep.xml	QPSLHMSAAAASR	QPSLHM[147]SAAAASR	IDCSSSIR.QPSLHMSAAAASR.DITIFHAM	R	D	13	3	504.7689	1341.6572	1341.6520	448.2263	448.2246	1341.6458	448.2225	0.0062	0.00056625420000	19.3570	17.2120	0.9920	2	0	215	227	600742.7	6M(15.9949)		0.00	false	sp|O94776|MTA2_HUMAN	O94776	MTA2_HUMAN	MTA2	Metastasis-associated protein MTA2	MTA1, MTA3	sp|Q13330|MTA1_HUMAN, sp|Q9BTC8|MTA3_HUMAN
20240206_EX1_UM3_6579035_SA_EXT00_SS16_pH7p5-single_res30k.03853.03853.4	D:\02-February\6579035\SS16\MSFragger3\4_res30k_1\interact.pep.xml	VHGPGIQSGTTNKPNK		GCDPSRVR.VHGPGIQSGTTNKPNK.FTVETRGA	R	F	16	4	504.9762	1633.8644	1633.8582	409.4734	409.4718	1633.8535	409.4707	0.0046	0.02077550000000	15.4610	11.8930	0.4952	2	1	1360	1375	557923.06			0.00	true	sp|P21333|FLNA_HUMAN	P21333	FLNA_HUMAN	FLNA	Filamin-A		
20240206_EX1_UM3_6579035_SA_EXT00_SS16_pH7p5-single_res30k.03877.03877.3	D:\02-February\6579035\SS16\MSFragger3\4_res30k_1\interact.pep.xml	NMSVIAHVDHGK	NM[147]SVIAHVDHGK	MDKKANIR.NMSVIAHVDHGK.STITDSIV	R	S	12	3	506.8871	1322.6461	1322.6394	441.8893	441.8871	1322.6400	441.8873	-0.0006	0.00004561432000	25.7860	22.2870	1.0000	2	0	21	32	2.6859726E7	2M(15.9949)		0.00	true	sp|P13639|EF2_HUMAN	P13639	EF2_HUMAN	EEF2	Elongation factor 2		
20240206_EX1_UM3_6579035_SA_EXT00_SS16_pH7p5-single_res30k.03891.03891.3	D:\02-February\6579035\SS16\MSFragger3\4_res30k_1\interact.pep.xml	NFSIVAHVDHGK		RFPVENIR.NFSIVAHVDHGK.STIADRII	R	S	12	3	507.9585	1322.6979	1322.6927	441.9066	441.9048	1322.6731	441.8983	0.0196	0.04474558000000	16.8970	11.0430	0.3171	2	0	70	81	0			0.00	true	sp|Q8N442|GUF1_HUMAN	Q8N442	GUF1_HUMAN	GUF1	Translation factor GUF1, mitochondrial		
20240206_EX1_UM3_6579035_SA_EXT00_SS16_pH7p5-single_res30k.03897.03897.4	D:\02-February\6579035\SS16\MSFragger3\4_res30k_1\interact.pep.xml	HVLHVQLNRPNKR		IRVTSAQK.HVLHVQLNRPNKR.NAMNKVFW	K	N	13	4	508.3719	1609.9363	1609.9271	403.4914	403.4891	1609.9276	403.4892	-0.0004	0.00000018676570	30.2390	14.3650	1.0000	2	1	66	78	6.043804E7			0.00	true	sp|Q13011|ECH1_HUMAN	Q13011	ECH1_HUMAN	ECH1	Delta(3,5)-Delta(2,4)-dienoyl-CoA isomerase, mitochondrial		
20240206_EX1_UM3_6579035_SA_EXT00_SS16_pH7p5-single_res30k.03907.03907.3	D:\02-February\6579035\SS16\MSFragger3\4_res30k_1\interact.pep.xml	VQVSYKGETK		INDGDKPK.VQVSYKGETK.AFYPEEIS	K	A	10	3	509.1674	1137.6083	1137.6039	380.2100	380.2086	1137.6029	380.2082	0.0009	0.00213765000000	15.3200	11.4920	0.9744	2	1	103	112	1620586.8			0.00	false	sp|P0DMV8|HS71A_HUMAN	P0DMV8	HS71A_HUMAN	HSPA1A	Heat shock 70 kDa protein 1A	HSPA1B	sp|P0DMV9|HS71B_HUMAN
20240206_EX1_UM3_6579035_SA_EXT00_SS16_pH7p5-single_res30k.03908.03908.5	D:\02-February\6579035\SS16\MSFragger3\4_res30k_1\interact.pep.xml	PIRPGQHPAASPTHPSAIR		GHSAQIAK.PIRPGQHPAASPTHPSAIR.GGGAFVQN	K	G	19	5	509.2365	1989.0795	1989.0684	398.8232	398.8210	1989.0656	398.8204	0.0028	0.00000001022549	31.6960	11.3420	1.0000	2	1	923	941	1701403.9			0.00	true	sp|P33176|KINH_HUMAN	P33176	KINH_HUMAN	KIF5B	Kinesin-1 heavy chain		
20240206_EX1_UM3_6579035_SA_EXT00_SS16_pH7p5-single_res30k.03915.03915.4	D:\02-February\6579035\SS16\MSFragger3\4_res30k_1\interact.pep.xml	SFSRPDHLNSHVR		YNCSHCGK.SFSRPDHLNSHVR.QVHSTERP	K	Q	13	4	509.8240	1551.7808	1551.7749	388.9525	388.9510	1550.7701	388.6998	1.0047	0.15824640000000	13.3050	10.9650	0.2435	2	1	345	357	550178.06			0.00	true	sp|P56270|MAZ_HUMAN	P56270	MAZ_HUMAN	MAZ	Myc-associated zinc finger protein		
20240206_EX1_UM3_6579035_SA_EXT00_SS16_pH7p5-single_res30k.03918.03918.4	D:\02-February\6579035\SS16\MSFragger3\4_res30k_1\interact.pep.xml	KPLTSSSAAPQRPISTQR		APAINKPK.KPLTSSSAAPQRPISTQR.TAAAPKAG	K	T	18	4	510.0313	1924.0569	1924.0483	482.0215	482.0194	1924.0490	482.0195	-0.0006	0.00000000048128	41.6260	13.2400	1.0000	2	1	151	168	6767590.5			0.00	true	sp|Q15691|MARE1_HUMAN	Q15691	MARE1_HUMAN	MAPRE1	Microtubule-associated protein RP/EB family member 1		
20240206_EX1_UM3_6579035_SA_EXT00_SS16_pH7p5-single_res30k.03919.03919.3	D:\02-February\6579035\SS16\MSFragger3\4_res30k_1\interact.pep.xml	DAVTYTEHAK		VFIENVIR.DAVTYTEHAK.RKTVTAMD	R	R	10	3	510.1004	1133.5382	1133.5359	378.8533	378.8526	1133.5352	378.8523	0.0007	0.32441770000000	14.4910	10.6000	0.8668	2	0	69	78	1830766.6			0.00	true	sp|P62805|H4_HUMAN	P62805	H4_HUMAN	H4C1	Histone H4		
20240206_EX1_UM3_6579035_SA_EXT00_SS16_pH7p5-single_res30k.03926.03926.3	D:\02-February\6579035\SS16\MSFragger3\4_res30k_1\interact.pep.xml	EDSQRPGAHLTVK		EPKRAVSR.EDSQRPGAHLTVK.KIFVGGIK	R	K	13	3	510.5855	1436.7423	1436.7379	479.9214	479.9199	1436.7370	479.9196	0.0008	0.03654860000000	15.5510	11.6570	0.9056	2	1	93	105	655305.7			0.00	false	sp|P09651|ROA1_HUMAN	P09651	ROA1_HUMAN	HNRNPA1	Heterogeneous nuclear ribonucleoprotein A1	HNRNPA1L2	sp|Q32P51|RA1L2_HUMAN
";

const DATA_V22: &str = r"Spectrum	Spectrum File	Peptide	Modified Peptide	Extended Peptide	Prev AA	Next AA	Peptide Length	Charge	Retention	Observed Mass	Calibrated Observed Mass	Observed M/Z	Calibrated Observed M/Z	Calculated Peptide Mass	Calculated M/Z	Delta Mass	Expectation	Hyperscore	Nextscore	Probability	Number of Enzymatic Termini	Number of Missed Cleavages	Protein Start	Protein End	Intensity	Assigned Modifications	Observed Modifications	Purity	Is Unique	Protein	Protein ID	Entry Name	Gene	Protein Description	Mapped Genes	Mapped Proteins
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1A_Alk14_R1.04252.04252.2	D:\06-June\6579035\SS25\MSFragger_prenylation_saturation_2\alk14_1\interact.pep.xml	HAVSEGTK		IIPGEIAK.HAVSEGTK.AVTKYTSS	K	A	8	2	484.2465	827.4148	827.4143	414.7147	414.7144	827.4137	414.7141	0.0006	0.02229718000000	12.1070	0.0000	0.9783	2	0	110	117	321365.75			0.00	false	sp|P58876|H2B1D_HUMAN	P58876	H2B1D_HUMAN	H2BC5	Histone H2B type 1-D	H2BC1, H2BC11, H2BC12, H2BC12L, H2BC13, H2BC14, H2BC15, H2BC17, H2BC18, H2BC21, H2BC26, H2BC3, H2BC4, H2BC9, H2BK1	sp|A0A2R8Y619|H2BK1_HUMAN, sp|O60814|H2B1K_HUMAN, sp|P06899|H2B1J_HUMAN, sp|P23527|H2B1O_HUMAN, sp|P33778|H2B1B_HUMAN, sp|P57053|H2BFS_HUMAN, sp|P62807|H2B1C_HUMAN, sp|Q16778|H2B2E_HUMAN, sp|Q5QNW6|H2B2F_HUMAN, sp|Q8N257|H2B3B_HUMAN, sp|Q93079|H2B1H_HUMAN, sp|Q96A08|H2B1A_HUMAN, sp|Q99877|H2B1N_HUMAN, sp|Q99879|H2B1M_HUMAN, sp|Q99880|H2B1L_HUMAN
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1A_Alk14_R1.04340.04340.4	D:\06-June\6579035\SS25\MSFragger_prenylation_saturation_2\alk14_1\interact.pep.xml	HAVSEGTKAVTKYTSSK		IIPGEIAK.HAVSEGTKAVTKYTSSK.	K	-	17	4	494.4629	1792.9319	1792.9276	449.2403	449.2392	1792.9319	449.2403	-0.0042	0.00000000000000	44.7880	9.8410	1.0000	2	2	110	126	0			0.00	false	sp|P58876|H2B1D_HUMAN	P58876	H2B1D_HUMAN	H2BC5	Histone H2B type 1-D	H2BC1, H2BC13, H2BC14, H2BC15, H2BC17, H2BC18, H2BC21, H2BC26, H2BC3, H2BC4, H2BC9, H2BK1	sp|A0A2R8Y619|H2BK1_HUMAN, sp|P23527|H2B1O_HUMAN, sp|P33778|H2B1B_HUMAN, sp|P62807|H2B1C_HUMAN, sp|Q16778|H2B2E_HUMAN, sp|Q5QNW6|H2B2F_HUMAN, sp|Q8N257|H2B3B_HUMAN, sp|Q93079|H2B1H_HUMAN, sp|Q96A08|H2B1A_HUMAN, sp|Q99877|H2B1N_HUMAN, sp|Q99879|H2B1M_HUMAN, sp|Q99880|H2B1L_HUMAN
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1A_Alk14_R1.04491.04491.3	D:\06-June\6579035\SS25\MSFragger_prenylation_saturation_2\alk14_1\interact.pep.xml	RMHVQLSTSR		DNTEFQGK.RMHVQLSTSR.LRTAPGMG	K	L	10	3	506.0050	1213.6370	1213.6338	405.5529	405.5519	1213.6349	405.5522	-0.0011	0.00000000032271	22.2990	9.9590	1.0000	2	0	140	149	9287616.0			0.00	false	sp|Q9BWF3|RBM4_HUMAN	Q9BWF3	RBM4_HUMAN	RBM4	RNA-binding protein 4	RBM4B	sp|Q9BQ04|RBM4B_HUMAN
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1A_Alk14_R1.04546.04546.3	D:\06-June\6579035\SS25\MSFragger_prenylation_saturation_2\alk14_1\interact.pep.xml	AGLLPNHRPR		ECVKMAHR.AGLLPNHRPR.LPEGVVPK	R	L	10	3	510.2081	1129.6461	1129.6453	377.5560	377.5557	1129.6467	377.5562	-0.0014	0.00002549502000	20.6210	9.6520	1.0000	2	1	125	134	1.2632305E7			0.00	true	sp|Q9NVS2|RT18A_HUMAN	Q9NVS2	RT18A_HUMAN	MRPS18A	Large ribosomal subunit protein mL66		
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1A_Alk14_R1.04553.04553.3	D:\06-June\6579035\SS25\MSFragger_prenylation_saturation_2\alk14_1\interact.pep.xml	ANGTTVHVGIHPSK		IERVQREK.ANGTTVHVGIHPSK.VVITRIKI	K	V	14	3	510.7931	1416.7445	1416.7446	473.2554	473.2555	1416.7473	473.2564	-0.0026	0.00000025932230	26.9160	10.1060	1.0000	2	0	90	103	7.1209952E7			0.00	false	sp|P61254|RL26_HUMAN	P61254	RL26_HUMAN	RPL26	Large ribosomal subunit protein uL24	RPL26L1	sp|Q9UNX3|RL26L_HUMAN
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1A_Alk14_R1.04619.04619.4	D:\06-June\6579035\SS25\MSFragger_prenylation_saturation_2\alk14_1\interact.pep.xml	RPAVVYIGSAGKPHER		RIARSYIR.RPAVVYIGSAGKPHER.VEQKVFIM	R	V	16	4	515.7570	1735.9473	1735.9463	434.9941	434.9939	1735.9480	434.9943	-0.0017	0.00000031691890	27.8760	9.0960	1.0000	2	1	623	638	1.5170657E7			0.00	true	sp|Q9BUQ8|DDX23_HUMAN	Q9BUQ8	DDX23_HUMAN	DDX23	Probable ATP-dependent RNA helicase DDX23		
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1A_Alk14_R1.04649.04649.3	D:\06-June\6579035\SS25\MSFragger_prenylation_saturation_2\alk14_1\interact.pep.xml	AVHAHVNLGYTK		IWGDAFKR.AVHAHVNLGYTK.LVGVFHTE	R	L	12	3	518.1349	1308.6947	1308.6926	437.2388	437.2381	1308.6938	437.2385	-0.0012	0.00000000006757	35.3800	14.3330	1.0000	2	0	168	179	4.725824E7			0.00	true	sp|Q9UFN0|NPS3A_HUMAN	Q9UFN0	NPS3A_HUMAN	NIPSNAP3A	Protein NipSnap homolog 3A		
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1A_Alk14_R1.04660.04660.3	D:\06-June\6579035\SS25\MSFragger_prenylation_saturation_2\alk14_1\interact.pep.xml	THIDVIHYRK		SNVKSVYK.THIDVIHYRK.TDAKRIHG	K	T	10	3	518.8942	1280.7026	1280.6997	427.9081	427.9072	1280.6989	427.9069	0.0008	0.00011077460000	19.4670	11.0210	1.0000	2	0	414	423	6867863.0			0.00	true	sp|P33991|MCM4_HUMAN	P33991	MCM4_HUMAN	MCM4	DNA replication licensing factor MCM4		
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1A_Alk14_R1.04683.04683.3	D:\06-June\6579035\SS25\MSFragger_prenylation_saturation_2\alk14_1\interact.pep.xml	RVLIAAHGNSLR		VPQIKEGK.RVLIAAHGNSLR.GIVKHIEG	K	G	12	3	520.6865	1305.7615	1305.7611	436.2611	436.2610	1305.7628	436.2615	-0.0017	0.00000000431067	40.8080	7.9910	1.0000	2	0	180	191	9.3708448E7			0.00	false	sp|P18669|PGAM1_HUMAN	P18669	PGAM1_HUMAN	PGAM1	Phosphoglycerate mutase 1	PGAM2	sp|P15259|PGAM2_HUMAN
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1A_Alk14_R1.04718.04718.3	D:\06-June\6579035\SS25\MSFragger_prenylation_saturation_2\alk14_1\interact.pep.xml	HVVFIAQRR		IEKKFSGK.HVVFIAQRR.LIPKPTRK	K	L	9	3	523.4083	1124.6582	1124.6559	375.8933	375.8926	1124.6566	375.8928	-0.0007	0.00000017667560	22.9960	8.1880	1.0000	2	0	91	99	8.2412536E7			0.00	true	sp|P62081|RS7_HUMAN	P62081	RS7_HUMAN	RPS7	Small ribosomal subunit protein eS7		
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1A_Alk14_R1.04721.04721.3	D:\06-June\6579035\SS25\MSFragger_prenylation_saturation_2\alk14_1\interact.pep.xml	RHWGGNVLGPK		NDRYDEIR.RHWGGNVLGPK.SVARIAKI	R	S	11	3	523.6148	1219.6594	1219.6570	407.5604	407.5596	1219.6573	407.5597	-0.0003	0.00000000005102	31.9860	8.3700	1.0000	2	0	235	245	5.2442392E7			0.00	true	sp|P62424|RL7A_HUMAN	P62424	RL7A_HUMAN	RPL7A	Large ribosomal subunit protein eL8		
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1A_Alk14_R1.04726.04726.3	D:\06-June\6579035\SS25\MSFragger_prenylation_saturation_2\alk14_1\interact.pep.xml	GHQQLYWSHPR		.GHQQLYWSHPR.KFGQGSRS	M	K	11	3	523.9589	1407.6802	1407.6780	470.2340	470.2333	1407.6796	470.2338	-0.0015	0.00000000001267	25.6250	10.4470	1.0000	2	0	2	12	2.8538076E7			0.00	true	sp|P62273|RS29_HUMAN	P62273	RS29_HUMAN	RPS29	Small ribosomal subunit protein uS14		
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1A_Alk14_R1.04735.04735.3	D:\06-June\6579035\SS25\MSFragger_prenylation_saturation_2\alk14_1\interact.pep.xml	WKPGSLASHVK		DYKNTFPK.WKPGSLASHVK.NIDENGID	K	N	11	3	524.6812	1208.6672	1208.6643	403.8963	403.8954	1208.6665	403.8961	-0.0022	0.00001025624000	23.8940	12.8410	1.0000	2	1	244	254	5.925636E7			0.00	true	sp|P06493|CDK1_HUMAN	P06493	CDK1_HUMAN	CDK1	Cyclin-dependent kinase 1		
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1A_Alk14_R1.04747.04747.3	D:\06-June\6579035\SS25\MSFragger_prenylation_saturation_2\alk14_1\interact.pep.xml	FRHPLLHIQK		FIHADCDK.FRHPLLHIQK.TPADCPVI	K	T	10	3	525.6157	1287.7577	1287.7532	430.2598	430.2583	1287.7563	430.2594	-0.0031	0.00000150199200	24.3750	10.7420	1.0000	2	1	304	313	1.504445E7			0.00	true	sp|Q9BS26|ERP44_HUMAN	Q9BS26	ERP44_HUMAN	ERP44	Endoplasmic reticulum resident protein 44		
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1A_Alk14_R1.04766.04766.3	D:\06-June\6579035\SS25\MSFragger_prenylation_saturation_2\alk14_1\interact.pep.xml	RIFQIHTSR		IPDEKTKK.RIFQIHTSR.MTIADDVT	K	M	9	3	527.0301	1156.6490	1156.6438	386.5569	386.5552	1156.6465	386.5561	-0.0026	0.04049933000000	14.5390	10.9220	0.9244	2	0	363	371	1.713694E7			0.00	true	sp|P62191|PRS4_HUMAN	P62191	PRS4_HUMAN	PSMC1	26S proteasome regulatory subunit 4		
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1A_Alk14_R1.04769.04769.2	D:\06-June\6579035\SS25\MSFragger_prenylation_saturation_2\alk14_1\interact.pep.xml	RVTIMPK		NICVIHAK.RVTIMPK.DIQIARRI	K	D	7	2	527.2379	843.5018	843.4990	422.7582	422.7568	843.5001	422.7573	-0.0010	0.05588001000000	15.5580	3.6740	0.9270	2	0	117	123	1.37811056E8			0.00	false	sp|Q16695|H31T_HUMAN	Q16695	H31T_HUMAN	H3-4	Histone H3.1t	H3-3A, H3-5, H3-7, H3C1, H3C15	sp|P68431|H31_HUMAN, sp|P84243|H33_HUMAN, sp|Q5TEC6|H37_HUMAN, sp|Q6NXT2|H3C_HUMAN, sp|Q71DI3|H32_HUMAN
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1A_Alk14_R1.04779.04779.2	D:\06-June\6579035\SS25\MSFragger_prenylation_saturation_2\alk14_1\interact.pep.xml	HQGVMVGMGQK		PSIVGRPR.HQGVMVGMGQK.DSYVGDEA	R	D	11	2	528.0311	1170.5646	1170.5616	586.2896	586.2881	1170.5637	586.2891	-0.0020	0.00809985400000	12.8830	0.0000	0.9864	2	0	40	50	1.4142689E7			0.00	false	sp|P60709|ACTB_HUMAN	P60709	ACTB_HUMAN	ACTB	Actin, cytoplasmic 1	ACTA1, ACTA2, ACTBL2, ACTC1, ACTG1, ACTG2	sp|P62736|ACTA_HUMAN, sp|P63261|ACTG_HUMAN, sp|P63267|ACTH_HUMAN, sp|P68032|ACTC_HUMAN, sp|P68133|ACTS_HUMAN, sp|Q562R1|ACTBL_HUMAN
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1A_Alk14_R1.04780.04780.3	D:\06-June\6579035\SS25\MSFragger_prenylation_saturation_2\alk14_1\interact.pep.xml	SRKESYSVYVYK		KDGKKRKR.SRKESYSVYVYK.VIKQVHPD	R	V	12	3	528.0998	1507.7682	1507.7700	503.5967	503.5973	1507.7670	503.5963	0.0030	0.00000000098314	27.6860	11.1380	1.0000	2	1	33	44	1.9093278E7			0.00	false	sp|P58876|H2B1D_HUMAN	P58876	H2B1D_HUMAN	H2BC5	Histone H2B type 1-D	H2BC12, H2BC12L, H2BC13, H2BC14, H2BC15, H2BC18, H2BC4, H2BC9	sp|O60814|H2B1K_HUMAN, sp|P57053|H2BFS_HUMAN, sp|P62807|H2B1C_HUMAN, sp|Q5QNW6|H2B2F_HUMAN, sp|Q93079|H2B1H_HUMAN, sp|Q99877|H2B1N_HUMAN, sp|Q99879|H2B1M_HUMAN, sp|Q99880|H2B1L_HUMAN
20240621_EX2_UM2_6579035_SA_EXT00_SS25_1A_Alk14_R1.04787.04787.2	D:\06-June\6579035\SS25\MSFragger_prenylation_saturation_2\alk14_1\interact.pep.xml	YRPGTVALR		GGVKKPHR.YRPGTVALR.EIRRYQKS	R	E	9	2	528.6867	1031.5884	1031.5856	516.8015	516.8001	1031.5875	516.8010	-0.0019	0.00008008428000	24.2780	12.3330	0.9794	2	1	42	50	3.15076192E8			0.00	false	sp|Q16695|H31T_HUMAN	Q16695	H31T_HUMAN	H3-4	Histone H3.1t	H3-3A, H3-5, H3-7, H3C1, H3C15	sp|P68431|H31_HUMAN, sp|P84243|H33_HUMAN, sp|Q5TEC6|H37_HUMAN, sp|Q6NXT2|H3C_HUMAN, sp|Q71DI3|H32_HUMAN
";
