#![allow(clippy::missing_panics_doc)]
use std::io::{BufReader, Read};

use super::error::CustomError;
use super::{maxquant, IdentifiedPeptide, IdentifiedPeptideSource, MaxQuantData, MaxQuantFormat};

use super::csv::parse_csv_raw;

#[test]
fn maxquant_msms() {
    assert_eq!(
        open_file(
            BufReader::new(MAXQUANT_MSMS.as_bytes()),
            &maxquant::MSMS,
            None
        )
        .unwrap(),
        19
    );
}

#[test]
fn maxquant_msms_scans() {
    assert_eq!(
        open_file(
            BufReader::new(MAXQUANT_MSMS_SCANS.as_bytes()),
            &maxquant::MSMS_SCANS,
            None
        )
        .unwrap(),
        19
    );
}

#[test]
fn maxquant_novo_msms_scans() {
    assert_eq!(
        open_file(
            BufReader::new(MAXQUANT_NOVO_MSMS_SCANS.as_bytes()),
            &maxquant::NOVO_MSMS_SCANS,
            None
        )
        .unwrap(),
        19
    );
}

#[test]
fn maxquant_novo_msms_scans_new() {
    assert_eq!(
        open_file(
            BufReader::new(MAXQUANT_NOVO_MSMS_SCANS_NEW.as_bytes()),
            &maxquant::NOVO_MSMS_SCANS,
            None
        )
        .unwrap(),
        19
    );
}

#[test]
fn maxquant_silac() {
    assert_eq!(
        open_file(
            BufReader::new(MAXQUANT_SILAC.as_bytes()),
            &maxquant::SILAC,
            None
        )
        .unwrap(),
        19
    );
}

/// Open a MaxQuant file from the given reader.
/// # Errors
/// If any part of the process errors.
fn open_file(
    reader: impl Read,
    format: &MaxQuantFormat,
    custom_database: Option<&super::ontologies::CustomDatabase>,
) -> Result<usize, CustomError> {
    let lines = parse_csv_raw(reader, b'\t', None)?;
    let mut num_lines = 0;
    for line in lines {
        let line = line?;
        let _read: IdentifiedPeptide =
            MaxQuantData::parse_specific(&line, format, custom_database)?.into();
        num_lines += 1;
    }
    Ok(num_lines)
}

const MAXQUANT_MSMS: &str = "Raw file	Scan number	Scan index	Sequence	Length	Missed cleavages	Modifications	Modified sequence	Oxidation (M) Probabilities	oxidation(w) Probabilities	Oxidation (M) Score diffs	oxidation(w) Score diffs	Gln->pyro-Glu	Glu->pyro-Glu	Oxidation (M)	oxidation(w)	Proteins	Charge	Fragmentation	Mass analyzer	Type	Scan event number	Isotope index	m/z	Mass	Mass error [ppm]	Mass error [Da]	Simple mass error [ppm]	Retention time	PEP	Score	Delta score	Score diff	Localization prob	Combinatorics	PIF	Fraction of total spectrum	Base peak fraction	Precursor full scan number	Precursor Intensity	Precursor apex fraction	Precursor apex offset	Precursor apex offset time	Matches	Intensities	Mass deviations [Da]	Mass deviations [ppm]	Masses	Number of matches	Intensity coverage	Peak coverage	Unfragmented precursor intensity	Unfragmented precursor fraction	Neutral loss level	ETD identification type	Reverse	All scores	All sequences	All modified sequences	MS3 scan numbers	Reporter PIF	Reporter fraction	id	Protein group IDs	Peptide ID	Mod. peptide ID	Evidence ID	Oxidation (M) site IDs	oxidation(w) site IDs	Mass deficit
20220225_L1_UM8_Peng0013_SA_mab_A_1_tryp	13268	9541	AAPSVTLFPPSSEELQANK	19	0	Unmodified	_AAPSVTLFPPSSEELQANK_					0	0	0	0	IGLC3;IGLC2;IGLC6;IGLC7	3	ETHCD	FTMS	MSMS	6		662.67747	1985.0106	NaN	NaN	1.8636318	58.734	0.017559	57.352	54.205	NaN	NaN	1	0	0	0	13262	6123579.5	0.4944330476421861	6	-0.2669410705566406	y7;y10;y11;y13;y14;c3;c5;c6;c11;c12;c14;c15;c16;c17;c18;z°1;z°2;z°3;z°7;z°8;z°12;z°13;z°15;z°16;z'2;z'18	2770.971435546875;10292.0849609375;54295.921875;4390.515625;1351.7666015625;6203.7548828125;3477.310302734375;6202.57666015625;12855.75390625;14654.42578125;21939.880859375;31883.1640625;30842.6640625;14824.419921875;24749.46875;3728.290771484375;1238.7689208984375;9095.4375;2436.718994140625;6729.138671875;21537.138671875;19962.28515625;9211.7431640625;5796.3505859375;2133.27783203125;3119.4990234375	0.007465081987561462;0.0016557981921323517;-0.0006528410613100277;0.0011892476247794548;0.0022059764876303234;-0.0001424394082505387;-0.0017716840594061978;-0.001725394306618;-0.0014198162411958037;-0.0010817414868142805;-0.0017515587519483233;0.010050551253925732;-0.00041923705339286244;-0.003696086472928073;0.002471265092935937;-0.00011240368280596158;-0.0005504349984164492;-0.0009356147507446622;-0.0018595733498614209;-0.0010790430047791233;-0.0011147231489303522;0.0005530898861252354;-0.0023915377585126407;-0.002475787596495138;-0.00038531500780436545;0.018494814423092976	8.978786860325311;1.5018089527057223;-0.5442197465989401;0.8146973879207076;1.4133733688608707;-0.5538920393026521;-3.9969136505380667;-3.16987048628711;-1.3078626833153697;-0.9224901002266982;-1.2242516190414676;6.51030901412731;-0.2507609741134921;-2.1206536468428028;1.3308291526678353;-0.8574268673402518;-2.2454127508838386;-2.959166860812196;-2.280555143675931;-1.1957015599504723;-0.837733916839391;0.3830996046548967;-1.4548460483594012;-1.4303679683157235;-1.565397089972868;9.734362155893091	831.4132080078125;1102.535837963408;1199.5909104546615;1459.7415462625754;1560.7882080078125;257.1609594351082;443.2630310058594;544.3106631902067;1085.6003916226412;1172.6320819577868;1430.7179379674521;1543.7901998378463;1671.8592471375537;1742.8996377747733;1856.9363978704075;131.0941925048828;245.13755798339844;316.17505695095076;815.40380859375;902.4350564733049;1330.641062183549;1443.723458350914;1643.8424953688584;1730.8746080285964;246.1452178955078;1899.951340098477	26	0.03580576304537366	0.08176100628930817	0	0	None	Unknown		57.35223277771986;3.1467750414827766;1.7776555042975895	AAPSVTLFPPSSEELQANK;DIALERGQEADAVAAELSK;ANAQLEESSPPFLTVSPAK	_AAPSVTLFPPSSEELQANK_;_DIALERGQEADAVAAELSK_;_ANAQLEESSPPFLTVSPAK_				0	22	0	0	0			0.05746640861548258
20220225_L1_UM8_Peng0013_SA_mab_A_1_tryp	13447	9704	AAPSVTLFPPSSEELQANK	19	0	Unmodified	_AAPSVTLFPPSSEELQANK_					0	0	0	0	IGLC3;IGLC2;IGLC6;IGLC7	3	ETHCD	FTMS	MSMS	9		662.67747	1985.0106	NaN	NaN	2.3170299	59.502	0.00023293	125.28	113.2	NaN	NaN	1	0	0	0	13438	731249.625	0.059042914471177474	20	-1.0261764526367188	y1;y2;y10;y11;y12;y13;c3;c4;c5;c6;c11;c12;c13;c14;c15;c16;c17;c18;z°1;z°3;z°7;z°8;z°12;z°13;z°14;z°15;z°16;z'2;z'18	2392.554931640625;1138.020751953125;5723.35302734375;28788.640625;3949.9716796875;3274.597412109375;1994.0433349609375;1733.2158203125;2244.16796875;3484.68896484375;7114.0322265625;11712.7099609375;17419.87890625;18966.828125;8295.1748046875;22702.578125;15332.8994140625;13395.9970703125;691.71630859375;4937.03955078125;1239.6055908203125;4233.3212890625;16935.47265625;13415.6025390625;18506.494140625;9812.1220703125;3624.2197265625;1528.7862548828125;2496.37646484375	0.00024008368592376428;-0.0003352767312208016;-0.002703682795527129;-0.0007559904013305641;0.003873260041245885;-0.0013349320995530434;-1.0641018775459088E-05;-0.0009717330719354322;-0.00015425241878119778;-0.00011052589650262234;0.003858371944488681;0.0036041633063632617;0.0034277112094969198;0.0026071805975789175;0.003863670350256143;0.003938819510040048;0.007346484198251346;0.0030827725192921207;0.0004369127234440384;-7.299973748331468E-05;-0.0019206085061114209;-0.000940937171776568;0.002071167940584928;0.0003968143205383967;-0.013600823359183778;0.0036192893871884735;-0.006934674250715034;0.00014874260938313455;0.0045724411361334205	1.6319726830532497;-1.2838175088469388;-2.4522305869609653;-0.6302067894450941;2.8762085474484027;-0.91449736058771;-0.04137884791104829;-2.823214780595352;-0.3479942400972605;-0.2030572463261335;3.554153751007683;3.073579312998058;2.63331779438421;1.8222938786850273;2.502707211582579;2.35595776628987;4.2151197835975465;1.660139538443642;3.332829211374332;-0.23088455285427847;-2.355407642332502;-1.042664853304599;1.556522610310627;0.2748547689587114;-8.804345458703771;2.201733214479358;-4.006446425557574;0.6042893434216744;2.406591965889362	147.11256408691406;261.15606689453125;1102.5401974443957;1199.5910136040015;1346.6547982697589;1459.7440704422997;257.16082763671875;344.1938171386719;443.26141357421875;544.3090483217966;1085.5951134344555;1172.6273960529936;1301.6701656012906;1430.7135792281026;1543.79638671875;1671.8548890809902;1742.888595204102;1856.9357863629812;131.09364318847656;316.1741943359375;815.4038696289062;902.4349183674719;1330.6378762924594;1443.7236146264795;1544.7852907382592;1643.8364845417127;1730.8790669152506;246.14468383789062;1899.965262471764	29	0.2438005750924478	0.13302752293577982	0	0	None	Unknown		125.2790195118964;12.080040696317239;4.44412852167444	AAPSVTLFPPSSEELQANK;DIALERGQEADAVAAELSK;ANAQLEESSPPFLTVSPAK	_AAPSVTLFPPSSEELQANK_;_DIALERGQEADAVAAELSK_;_ANAQLEESSPPFLTVSPAK_				1	22	0	0	1			0.05746640861548258
20220225_L1_UM8_Peng0013_SA_mab_A_1_tryp	13448	9705	AAPSVTLFPPSSEELQANK	19	0	Unmodified	_AAPSVTLFPPSSEELQANK_					0	0	0	0	IGLC3;IGLC2;IGLC6;IGLC7	3	CID	FTMS	MSMS	10		662.67747	1985.0106	NaN	NaN	2.3170299	59.508	0.017189	54.355	52.994	NaN	NaN	1	0	0	0	13438	731249.625	0.059042914471177474	20	-1.0261764526367188	y1;y2;y3;y4;y5;y6;y7;y8;y9;y10;y11;y12;y8-H2O;y9-H2O;y10-H2O;y11-H2O;y1-NH3;y2-NH3;y4-NH3;y7-NH3;b2;b3;b7;b8;b7-H2O;b8-H2O	11437.2421875;5517.70068359375;5879.0009765625;4730.2265625;2970.7822265625;4980.73828125;2117.119384765625;6560.4169921875;10804.98828125;44862.828125;120878.375;930.1884765625;1072.8460693359375;1674.8443603515625;6898.1044921875;20218.55078125;8163.56689453125;2836.39013671875;2594.78662109375;2090.646728515625;5731.69873046875;3415.752685546875;4531.10107421875;5592.41357421875;4047.81640625;4588.69140625	0.0004537067327987643;-0.0007320052468458016;-0.0001172408843217454;-0.0015067704999296438;0.000770100525073758;0.0007212024694354113;-4.2242231188538426E-05;0.0017054358547738957;0.0010810405162828829;9.211668566422304E-05;0.0008874129032392375;0.0004684048001308838;0.00012021183761135035;-0.0003831165436167794;0.00577044710712471;0.0048527144460877025;0.000409121834366033;0.0003983366125339671;-0.0013529911405498751;0.01241012111256623;0.0004188371218845077;0.00034150259844523134;0.002035469266729706;-0.0006268376466778136;0.0005910298140179293;-4.296207168863475E-05	3.0840832286899045;-2.802937506085921;-0.3529300662714872;-3.2737879603562816;1.3431953490906334;1.0268019895696536;-0.05080728734509438;1.8568610215273191;1.075144799717809;0.08354971498181459;0.739763893615337;0.34782753266116284;0.13350314111846137;-0.38797611975000307;5.32073262122772;4.106988640020054;3.145014212629123;1.631665900735315;-3.052597203685159;15.238703056869129;2.9272710734908705;1.4221339049290416;3.1786108222755844;-0.7960495201307741;0.9496662387323807;-0.05583664199769213	147.1123504638672;261.1564636230469;332.1929626464844;460.2529296875;573.334716796875;702.3773587911306;831.4207153320312;918.4509960638453;1005.4836488690838;1102.5374016449146;1199.589370200697;1346.658203125;900.4420166015625;987.4745483398438;1084.521158628193;1181.574840212854;130.08584594726562;244.1287841796875;443.2262268066406;814.3817138671875;143.08108520507812;240.13392639160156;640.3644172055334;787.4354934286469;622.3552969586862;769.4243448667719	26	0.2383018669423918	0.06860158311345646	0	0	None	Unknown		54.35492206311417;1.3606151709937753;0.08398074589203781	AAPSVTLFPPSSEELQANK;ANAQLEESSPPFLTVSPAK;DIALERGQEADAVAAELSK	_AAPSVTLFPPSSEELQANK_;_ANAQLEESSPPFLTVSPAK_;_DIALERGQEADAVAAELSK_				2	22	0	0	2			0.05746640861548258
20220225_L1_UM8_Peng0013_SA_mab_A_1_tryp	3791	926	ADSSPVKAGVETTTPSK	17	1	Unmodified	_ADSSPVKAGVETTTPSK_					0	0	0	0	IGLC3;IGLC2	3	ETHCD	FTMS	MULTI-MSMS	3	0	558.95634	1673.8472	-0.1707	-9.5412E-05	1.0014431	15.164	5.0145E-10	243.85	243.1	NaN	NaN	1	0	0	0	3788	3170214.75	0.4891794131448263	1	-0.05173492431640625	y1;y2;y3;y4;y5;y6;y7;y8;y9;y10;y11;y13;y14;y15;y16;c5;c6;c7;c8;c9;c10;c11;c12;c13;c15;c16;z°2;z°6;z°7;z°8;z°9;z°10;z°11;z°12;z°15;z'2;z'14;z'15;z'16	1069.641845703125;1427.3017578125;6794.21337890625;5608.59765625;2870.093505859375;4402.34228515625;6480.9853515625;3026.68408203125;13829.4765625;3230.140625;2401.397705078125;34621.171875;8229.419921875;22665.79296875;3393.801513671875;3559.156005859375;4666.376953125;16885.724609375;17814.51171875;45735.4609375;49360.5;65120.60546875;34380.7265625;68158.8359375;11584.4716796875;12270.7724609375;624.2240600585938;8811.9404296875;10808.7353515625;22646.2421875;2063.09716796875;11537.7353515625;10736.537109375;19061.5859375;20420.15625;2044.6448974609375;54357.203125;21418.453125;10724.1494140625	0.00019430731873626428;-0.00024798590627028716;-8.628231222473914E-05;-0.00033583724922436886;-0.0018343758645187336;-0.0004671080984053333;-0.0016031060622481164;-0.0003149346663349206;0.00044581838074009283;0.0009328502505923097;0.006546583799945438;-0.0006529830270665116;-0.002323358987496249;0.0004101417810034036;-0.005504476517671719;-0.0006770351956788545;-0.0009922090680447582;-0.0012756668436395557;0.012089613954003653;0.003887326400672464;-0.0003370405810301236;-0.00035316493858772446;-0.0003409985260987014;0.0003133469074327877;0.0014105836789894965;0.0006869145265682164;-0.00023426233750001302;-0.00028062705814591027;-0.0016433411553862243;-0.00023312739335779042;0.001772549199927198;-0.0002156392357619552;0.0007737564108083461;-0.001675881648907307;-0.0017698452634249406;0.0002055158562370707;0.001767583557693797;0.0018371152409599745;0.003266849219926371	1.320806686230659;-1.059112178100857;-0.26051605046716203;-0.7769593047953183;-3.4397033435025426;-0.7363673884114101;-2.0999972796528854;-0.3651619837448609;0.48486311958968714;0.9417884982050355;5.852486859817912;-0.49666814633498685;-1.6574576335957614;0.27548665691255375;-3.4320975525615243;-1.424691253771411;-1.727732061841159;-1.8162077705715778;15.631711185097835;4.681085020087086;-0.362602065530619;-0.33363147697444023;-0.2940667430956344;0.24856123421394144;0.9669863673892065;0.44438201749616835;-1.0739754516644309;-0.45385247918471133;-2.1988434559010748;-0.27542327935672234;1.9619725353714244;-0.22128380775648995;0.7017653355576243;-1.394642800146632;-1.2017090963284704;0.9378558841084755;1.2746270159951463;1.2465348529791567;2.0561698504667225	147.11260986328125;234.14508056640625;331.19768271481223;432.2456107438492;533.2947877565645;634.3410989628983;763.3848280570621;862.4519538018662;919.4726567724192;990.5092835283493;1118.5986328125;1314.727010147527;1401.7607089333874;1488.790003842519;1603.8228614928175;475.21538009489564;574.2841091849681;702.3793556604437;773.403104167446;830.4327701785994;929.5054084617811;1058.5480176823385;1159.595683990026;1260.6427081186923;1458.7420532080207;1545.7748052870731;218.1263427734375;618.3221884124581;747.3661442227553;846.4331479251933;903.4526059722001;974.4917079484358;1102.585681570489;1201.6565451247486;1472.7734597601632;219.13372802734375;1386.745718953542;1473.7776778317589;1588.8031911297799	39	0.51109255548913	0.23780487804878048	0	0	None	Unknown		243.84832864421622;0.7523724219580439;4.890919548465482	ADSSPVKAGVETTTPSK;EKNKTENTRLGDNR;KGPQGVRDWGHYFK	_ADSSPVKAGVETTTPSK_;_EKNKTENTRLGDNR_;_KGPQGVRDWGHYFK_				3	22	1	1	3			0.03722462810446814
20220225_L1_UM8_Peng0013_SA_mab_A_1_tryp	3793	928	ADSSPVKAGVETTTPSK	17	1	Unmodified	_ADSSPVKAGVETTTPSK_					0	0	0	0	IGLC3;IGLC2	3	CID	FTMS	MULTI-MSMS	5	0	558.95634	1673.8472	-0.1707	-9.5412E-05	1.0014431	15.176	1.4196E-09	145.91	145.51	NaN	NaN	1	0	0	0	3788	3170214.75	0.4891794131448263	1	-0.05173492431640625	y1;y2;y3;y4;y5;y6;y7;y8;y9;y10;y11;y12;y13;y14;y15;y16;y2-H2O;y3-H2O;y4-H2O;y9-H2O;y10-H2O;y11-H2O;y13-H2O;y14-H2O;y15-H2O;y16-H2O;y1-NH3;a2;b2;b3;b9;b10;b11;b2-H2O;b3-H2O;b9-H2O	11385.203125;11658.4775390625;50454.765625;9413.6982421875;8218.3681640625;20444.41796875;19817.064453125;2460.017822265625;20466.576171875;27679.84375;37243.953125;7609.3623046875;126314.78125;26423.115234375;63468.04296875;18132.787109375;4077.80126953125;6007.12890625;1284.9398193359375;1319.905029296875;2708.3466796875;1135.5537109375;15483.392578125;4067.3857421875;13616.7900390625;3962.26220703125;6900.0478515625;20705.404296875;29162.271484375;6239.7041015625;7441.26171875;4134.34765625;1714.199462890625;1813.510498046875;10902.560546875;826.2374267578125	-3.457451720123572E-05;-8.013922658278716E-05;-0.0002132316770939724;-0.00014745668124760414;0.00026197697195584624;0.0008147800215283496;0.0013739397373910833;0.0016876953249038706;0.0027854438329768527;0.0032529913371490693;0.00035885998136109265;0.002075577092000458;0.00104320289210591;0.0013993782210945938;0.004283379691287337;0.002985451183803889;5.809239041809633E-06;-0.0004722171709659051;0.0010981597531554144;0.0006848771562317779;0.004964058907034996;0.0007426396873597696;0.0005112335286412417;0.002675749414038364;0.001474638164836506;-0.0010329486601676763;-3.3383048446467E-05;-5.838648127109991E-05;-9.310520155736413E-05;8.600400337854808E-05;0.0013427704309378896;0.0020828620440624945;0.004269712774885193;-0.00011396825937026733;-0.00022347437453618113;-0.004447982018632501	-0.2350203931632261;-0.3422633686631257;-0.6438197079569511;-0.34114110553535015;0.49124425700692226;1.2844535367268302;1.799806657141516;1.9568617548307279;3.029400493992924;3.2841680648308915;0.32081032977225693;1.7045459812187767;0.793475930696481;0.9983030117737881;2.877095375376596;1.8614692801951096;0.026877918316930517;-1.5077778167711748;2.6510638470228742;0.7597405857294816;5.104458636288538;0.674762695128222;0.39425272149991686;1.9337010311752076;1.0026243180095462;-0.6513706413235572;-0.2566223453961236;-0.36703403516072;-0.49769867773640936;0.31376496016448424;1.6507941488592426;2.2826474788767963;4.099513889285892;-0.6741255436436311;-0.8726296957000296;-5.592104220058404	147.1128387451172;234.14491271972656;331.1978096641771;432.24542236328125;533.292691403728;634.3398170747784;763.3818510112625;862.449951171875;919.470317146967;990.5069633872628;1118.6048205363186;1217.6715177354079;1314.7253139616078;1401.7569861961788;1488.7861306046086;1603.814371565116;216.13426208496094;313.18750396337094;414.2336120605469;901.4618530273438;972.4946876333929;1100.5938720703125;1296.7152812446711;1383.7451451386858;1470.778374659835;1585.80782527866;130.08628845214844;159.07647705078125;187.07142639160156;274.10327569229656;813.4087656330692;912.476439457656;1041.516845703125;169.06088256835938;256.09302048437445;795.4039916992188	36	0.4851026991720078	0.1276595744680851	0	0	None	Unknown		145.9147238706339;0.4034724850162738;0	ADSSPVKAGVETTTPSK;KGPQGVRDWGHYFK;EKNKTENTRLGDNR	_ADSSPVKAGVETTTPSK_;_KGPQGVRDWGHYFK_;_EKNKTENTRLGDNR_				4	22	1	1	3			0.03722462810446814
20220225_L1_UM8_Peng0013_SA_mab_A_1_tryp	4502	1573	AEAESLYQSK	10	0	Unmodified	_AEAESLYQSK_					0	0	0	0	CON__P04264	2	CID	FTMS	MULTI-SECPEP	10	1	563.27476	1124.535	0.064199	3.6162E-05	-42.614286	18.532	0.0093413	63.397	60.559	NaN	NaN	1	0	0	0	4492	4188466	1	0	0	y1;y2;y3;y4;y5;y6;y7;y8;y2-H2O;y3-H2O;y8-H2O;y1-NH3;y3-NH3;y8-NH3;a2;b2;b3;b2-H2O	9705.64453125;3664.5947265625;8873.484375;5727.84521484375;2691.141845703125;11258.736328125;7343.796875;12628.3662109375;1065.334228515625;1829.3828125;2371.490234375;7717.4580078125;5802.95361328125;3051.587646484375;13919.78515625;15643.8798828125;4950.951171875;1235.4481201171875	1.1201849986264278E-05;-0.00011065680470778716;-0.00024229247941320864;-0.0007288603200095167;0.002176811671347423;0.0009432948820631282;-0.00016659591426559928;0.001600404499981778;-0.00011626107345819037;-0.00023931119687858882;0.0024072288655361262;1.2393318741033E-05;0.0002204659541575893;-0.016050370048674267;-3.332228124008907E-05;-0.000113817368742275;0.0011454638080863333;-0.0002109743718676782	0.07614463542027781;-0.472599592277494;-0.6689399121687538;-1.387598442925977;3.4100671378794343;1.3004114081491067;-0.19498001473323587;1.7293052954833956;-0.537911049704461;-0.6952818272787055;2.652741216435183;0.09527001845937948;0.6387047333870081;-17.667823238400892;-0.19251185262232864;-0.5660103027257037;4.209361250263424;-1.1523828698620164	147.11279296875;234.1449432373047;362.20365238437944;525.26746749052;638.3486257989287;725.381887725618;854.4255907126143;925.4609375;216.13438415527344;344.1930847167969;907.4495659893345;130.08624267578125;345.1766405244459;908.4520391730487;173.09210205078125;201.08709716796875;272.1229516745919;183.07662963867188	18	0.0754429094736119	0.06338028169014084	0	0	None	Unknown		63.397346450043614;2.838168407726437	AEAESLYQSK;SKYEDEINK	_AEAESLYQSK_;_SKYEDEINK_				5	10	2	2	4			-0.022317763528008072
20220225_L1_UM8_Peng0013_SA_mab_A_1_tryp	4676	1731	AEFAEVSK	8	0	Unmodified	_AEFAEVSK_					0	0	0	0	CON__P02768-1	2	CID	FTMS	MULTI-SECPEP	8	-2	440.72418	879.4338	0.73624	0.00032448	-2615.0356	19.385	0.013517	60.91	45.274	NaN	NaN	1	0	0	0	4668	975130.875	0.3829557585428663	1	-0.05452537536621094	y1;y2;y3;y4;y5;y6;y7;y2-H2O;y7-H2O;y1-NH3;a2;b2;b3;b2-H2O	12548.267578125;7689.47607421875;3016.1357421875;3280.7705078125;7343.3828125;26562.33984375;1208.6219482421875;1839.626220703125;1252.1427001953125;8827.013671875;15996.1123046875;15709.392578125;4735.220703125;697.482177734375	0.0003621539984237643;0.00036236565622971284;0.000294836543787369;-0.0004470281937187792;0.00035084163744159014;0.000819828475414397;0.006804631381214676;0.00011262076247930963;0.003197952893742695;0.000317569099991033;0.00037866502344741093;0.000374463881257725;-7.889220324841517E-05;0.0002315305109448218	2.461749621305963;1.5476156917018682;0.8848291830146887;-0.9670570345000048;0.6578783125271117;1.20499120424446;8.407036437891703;0.5210687886735434;4.040930634242128;2.441225439844587;2.1876557061089765;1.8622019801859484;-0.22660049503970736;1.2646675385238557	147.11244201660156;234.14447021484375;333.21295166015625;462.25628662109375;533.2926025390625;680.3605474684246;809.3971557617188;216.1341552734375;791.3901977539062;130.0859375;173.09169006347656;201.08660888671875;348.15547615900323;183.07618713378906	14	0.13283424810960817	0.04861111111111111	0	0	None	Unknown		60.910261724254624;15.63621529709179	AEFAEVSK;INDYVEK	_AEFAEVSK_;_INDYVEK_				6	7	3	3	5			-0.010741832648591298
20220225_L1_UM8_Peng0013_SA_mab_A_1_tryp	7002	3845	ALEEANADLEVK	12	0	Unmodified	_ALEEANADLEVK_					0	0	0	0	CON__P02533;CON__P19012;CON__P08779;CON__Q6IFX2	2	ETHCD	FTMS	MULTI-SECPEP	4	-1	651.33281	1300.6511	-0.84552	-0.00055071	-1562.305	30.731	0.031676	51.252	51.252	NaN	NaN	1	0	0	0	6998	7268996	0.5453011689736142	3	-0.15655136108398438	y1;y2;y3;y6;y7;y8;y9;y10;c7;c10;c11;z°1;z°9;z°10;z°11;z'5;z'7;z'8	5373.37109375;1577.7828369140625;815.2266235351562;2980.42041015625;8943.4306640625;11231.48046875;10308.552734375;11888.888671875;2092.191162109375;4512.8828125;11158.18359375;516.40771484375;6829.2666015625;5679.8876953125;1266.7955322265625;2036.23681640625;3939.3349609375;5127.65234375	0.0004994830999862643;0.00040143640936207703;-6.577012499064949E-05;0.001596214633082127;-0.0014474204074303998;-0.00031194428788694495;-0.002310941638370423;0.0008522340972376696;0.0015095905624775696;-0.0072582039447297575;0.003497548256746086;0.0006810533484440384;-0.0014582299738776783;-0.002468856818495624;0.002523735662407489;-0.0006658028374886271;-0.0008748567586280842;0.0010895627265199437	3.39525032285559;1.6306567458185417;-0.17528235549590532;2.366970414353935;-1.8358580293853515;-0.3629570754215504;-2.3378340301745313;0.762600813740782;2.1073194197683707;-6.761137282409891;2.982790600583956;5.195176518349647;-1.499500269225261;-2.241316355492244;2.07783279527073;-1.131693039026805;-1.1311757035310626;1.2902784642683711	147.1123046875;246.18081665039062;375.223876953125;674.3703357685669;788.4163068508074;859.4522851624878;988.4968772560383;1117.5363071765028;716.3558349609375;1073.5182028640447;1172.5758610280432;131.09339904785156;972.4773004749738;1101.5209041980183;1214.5999755859375;588.3245849609375;773.4048352498586;844.4399846181734	18	0.03278880439947547	0.0743801652892562	0	0	None	Unknown		51.251918605769994	ALEEANADLEVK	_ALEEANADLEVK_				7	1	4	4	6			0.012761224272253457
20220225_L1_UM8_Peng0013_SA_mab_A_1_tryp	6101	3026	ALPAPIEK	8	0	Unmodified	_ALPAPIEK_					0	0	0	0	IGHG1;IGHG3	2	ETHCD	FTMS	MULTI-MSMS	3	0	419.75528	837.496	0.084003	3.5261E-05	2.2006388	26.357	0.0015361	89.805	36.237	NaN	NaN	1	0	0	0	6098	2577775872	1	0	0	y1;y2;y3;y4;y5;y6;y7;c6;c7;z°2;z°3;z°5;z°7;cm5;cm6;b2;b3;b4;b5;b6;b7	407527.875;436424.3125;224222.484375;6085128.5;1235023.375;49838736;146845.421875;13057215;88142368;311949.71875;3597496.5;8044905.5;5355391;5844145;5576037.5;2033199;145750.484375;1165793.375;116116.8671875;959092.25;1525875.25	-9.560967345123572E-05;-0.00022750001306803824;8.136438748351793E-05;-0.0002710028450110258;-0.0004925979942527192;-0.0008553833783935261;-0.0038127351760977035;0.00040342671297821653;8.168418162313174E-06;-0.0009940026286585635;-0.002125796786401679;-0.0006097671471252397;-0.0004698961857911854;-0.002008623005053778;-0.00013966109986540687;-7.054547342022488E-05;-0.0005140909343595013;-0.0003409053803693496;0.00043532620935593513;3.080486249018577E-05;-0.00041267243523179786	-0.649906796712168;-0.8238108974247409;0.20903431587013147;-0.5572836249444363;-0.883853629259718;-1.3071602305290444;-4.967927447543069;0.6951063193064667;0.011514150606956326;-3.821063821158362;-5.695783933114596;-1.1264631499060578;-0.6253210341605739;-4.307652166807542;-0.24105516335851537;-0.38106214860165044;-1.8218434283183755;-0.9651397466795286;0.9668100714553185;0.05468107222209562;-0.5960045185104109	147.11289978027344;276.15562476681305;389.2393798828125;486.292496102045;557.3298314849942;654.3829581223783;767.469979454576;580.3813053817871;709.4242937362819;260.1376672000286;373.22286297458635;541.3112245847472;751.4479125461858;466.291828419005;579.3740234375;185.12852478027344;282.1817321777344;353.21867277998035;450.2706604003906;563.3551289021376;692.3981654756353	21	0.44316940266891564	0.2	0	0	None	Unknown		89.80455506116458;53.56715335307032	ALPAPIEK;QLKPLEK	_ALPAPIEK_;_(Gln->pyro-Glu)QLKPLEK_				8	17;19	5	5	7			0.07075587874123812
20220225_L1_UM8_Peng0013_SA_mab_A_1_tryp	6102	3027	ALPAPIEK	8	0	Unmodified	_ALPAPIEK_					0	0	0	0	IGHG1;IGHG3	2	CID	FTMS	MULTI-MSMS	4	0	419.75528	837.496	0.084003	3.5261E-05	2.2006388	26.36	0.00035104	103.75	63.791	NaN	NaN	1	0	0	0	6098	2577775872	1	0	0	y1;y2;y3;y4;y5;y6;y7;y2-H2O;y3-H2O;y4-H2O;y5-H2O;y6-H2O;y1-NH3;a2;b2;b3;b4;b5	8786482;23411966;7583072.5;95766000;24069610;167679648;851528.875;25928710;295022.125;3926802.5;2541500.5;2050926.625;5705652.5;63019532;12984970;2135933.5;656759.8125;98786.2578125	-0.00015664482970123572;-0.0004884547629444569;-0.0006890952174671838;-0.0007497616860518974;-0.0005903384136445311;-0.0008453105923535986;0.0008217784983344245;-0.0003875772125638832;-0.001222899487856921;-0.0008040293527642461;-0.0009110444186717359;-0.00036238035829683213;-9.4418204696467E-05;-0.00012737948748053896;-0.0002536509421702249;-0.0005245478644724244;-0.0008285920779371736;-0.00029709566564406487	-1.0647928559997164;-1.7687646296879818;-1.770360063988727;-1.5417900829564357;-1.0592261112999857;-1.2917674503485639;1.070769519108;-1.5013921711472902;-3.2941817588360056;-1.7169751460197944;-1.6892474789932244;-0.56944745368271;-0.725811778626945;-0.8106441472334004;-1.3701329473264259;-1.858900790585686;-2.3458299284852684;-0.6598146592922385	147.1129608154297;276.1558857215629;389.24015034241745;486.29297486088603;557.3299292254136;654.3829480495923;767.4653449409016;258.1452201577125;371.23011946038787;468.2824644422528;539.3196852451186;636.3719004330583;130.0863494873047;157.1336669921875;185.1287078857422;282.1817426346645;353.2191604666779;450.2713928222656	18	0.6557330163377849	0.13043478260869565	0	0	None	Unknown		103.74828524460852;39.957323273324995	ALPAPIEK;QLKPLEK	_ALPAPIEK_;_(Gln->pyro-Glu)QLKPLEK_				9	17;19	5	5	7			0.07075587874123812
20220225_L1_UM8_Peng0013_SA_mab_A_1_tryp	6250	3162	ALPAPIEK	8	0	Unmodified	_ALPAPIEK_					0	0	0	0	IGHG1;IGHG3	2	ETHCD	FTMS	MULTI-MSMS	9	0	419.75528	837.496	0.084003	3.5261E-05	1.4842175	27.07	0.0031594	87.667	34.1	NaN	NaN	1	0	0	0	6241	56798284	0.022033833358806456	13	-0.6847209930419922	y1;y2;y3;y4;y5;y6;c6;c7;z°2;z°3;z°5;z°7;cm5;cm6;b2;b3;b4;b6;b7	8927.5615234375;6298.7822265625;4050.64208984375;110475.328125;20504.00390625;924406.5;258249.109375;1727996.375;5120.76025390625;69337.96875;158259.234375;101207.5390625;116242.875;111338.6328125;41508.77734375;3097.048095703125;24230.435546875;19181.978515625;29675.796875	-8.035088438873572E-05;-0.00036445195001988395;0.00026446985623351793;-0.00023095665954997457;-0.000773243584148986;-0.0010440967350859864;0.0002862460372625719;-0.00035228100011863717;-0.00013710533443145323;-0.0022224633750056455;-0.000686113877804928;-0.000830154637810665;-0.00226735530861788;-0.00038380172486540687;-7.054547342022488E-05;-0.0005446085124845013;-0.00025804984744581816;0.00011784632647504623;-0.00023103431817617093	-0.5461852280994549;-1.3197332829544905;0.6794532986995204;-0.47493366733093023;-1.3874067941403687;-1.5955434367995396;0.4932033075744512;-0.49657281860749025;-0.5270508786199724;-5.954787393418595;-1.267503332415704;-1.104739564723824;-4.862521520512396;-0.6624417864979715;-0.38106214860165044;-1.9299918863734142;-0.7305670052672323;0.2091866011988075;-0.33367271940293036	147.11288452148438;276.15576171875;389.23919677734375;486.29245605585953;557.3301121305841;654.383146835735;580.3814225624628;709.4246541857002;260.1368103027344;373.22295964117495;541.3113009314778;751.4482728046378;466.2920871513086;579.374267578125;185.12852478027344;282.1817626953125;353.21858992444743;563.3550418606736;692.3979838375183	19	0.43495459082681087	0.16666666666666666	0	0	None	Unknown		87.66728969367605;53.56715335307032	ALPAPIEK;QLKPLEK	_ALPAPIEK_;_(Gln->pyro-Glu)QLKPLEK_				10	17;19	5	5	7			0.07075587874123812
20220225_L1_UM8_Peng0013_SA_mab_A_1_tryp	6251	3163	ALPAPIEK	8	0	Unmodified	_ALPAPIEK_					0	0	0	0	IGHG1;IGHG3	2	CID	FTMS	MULTI-MSMS	10	0	419.75528	837.496	0.084003	3.5261E-05	1.4842175	27.075	0.00058215	98.457	63.308	NaN	NaN	1	0	0	0	6241	56798284	0.022033833358806456	13	-0.6847209930419922	y1;y2;y3;y4;y5;y6;y7;y2-H2O;y4-H2O;y5-H2O;y6-H2O;y1-NH3;a2;b2;b3;b4;b5	175896.1875;465640.65625;151269.53125;1953552;509048.6875;3616186.25;16652.1171875;512757.28125;78154.484375;48514.109375;34944.828125;121353.34375;1323182.625;274385.8125;46204.51171875;14041.39453125;2981.583984375	-0.00015664482970123572;-0.0004839734608594881;-0.0007089793524528432;-0.0008102675571990403;-0.0006471416804743058;-0.0009309601714448945;0.00016193788951568422;-0.0004058237832964551;-0.000848172206133313;-0.0008084681767286384;8.458532329314039E-05;-9.4418204696467E-05;-0.00012737948748053896;-0.00023839215310772488;-0.0004392055163293662;-0.0007666409957778342;-0.0008158944937690649	-1.0647928559997164;-1.7525372216803234;-1.8214444620147774;-1.6662125473130514;-1.1611463526044759;-1.422653283325908;0.21100333891894826;-1.5720754169437412;-1.8112404170209686;-1.4990521440513118;0.13291816097699394;-0.725811778626945;-0.8106441472334004;-1.2877104554943368;-1.556463735254012;-2.1704403838853707;-1.8120039751794346	147.1129608154297;276.15588124026084;389.24017022655244;486.2930353667572;557.3299860286804;654.3830336991714;767.4660047815104;258.14523840428325;468.28250858510614;539.3195826688767;636.3714534673767;130.0863494873047;157.1336669921875;185.12869262695312;282.18165729231634;353.21909851559576;450.27191162109375	17	0.6490253206405225	0.08808290155440414	0	0	None	Unknown		98.45717302686104;35.14937402923769	ALPAPIEK;QLKPLEK	_ALPAPIEK_;_(Gln->pyro-Glu)QLKPLEK_				11	17;19	5	5	7			0.07075587874123812
20220225_L1_UM8_Peng0013_SA_mab_A_1_tryp	6423	3319	ALPAPIEK	8	0	Unmodified	_ALPAPIEK_					0	0	0	0	IGHG1;IGHG3	2	ETHCD	FTMS	MULTI-MSMS	6	0	419.75528	837.496	0.084003	3.5261E-05	1.7230246	27.896	0.0057694	80.245	33.449	NaN	NaN	1	0	0	0	6417	9356928	0.0036298454422029752	29	-1.5782909393310547	y1;y2;y4;y5;y6;c6;c7;z°2;z°3;z°5;z°7;cm5;cm6;b2;b4;b6;b7	2253.980712890625;1774.723388671875;35432.37890625;6701.4306640625;288638.40625;79665.5390625;511361.15625;2167.537109375;19871.3125;45344.05078125;29318.681640625;35159.484375;34317.21875;12174.087890625;6755.92626953125;5816.830078125;8375.408203125	1.1201849986264278E-05;-0.00018134648126988395;0.0001756983911604948;0.0007072705654991296;-0.00041487652060823166;0.0009058946865252437;0.0006178604581918989;-0.0018881651254787357;-0.0017199111607055784;-0.00027326267900207313;0.0005081058975520136;-0.001665422746157219;0.00016551468138459313;-9.51031717022488E-06;9.122962921992439E-06;0.00037432432077366684;-0.000208732444434645	0.07614463542027781;-0.6566823027096451;0.3613022079570988;1.2690368399840048;-0.6339969504686408;1.5608625956909346;0.8709329447103252;-7.258305403047937;-4.608273505620332;-0.5048165204494223;0.6761700317006123;-3.571634479612978;0.28567861497270347;-0.05137144757663294;0.02582811347645514;0.6644557399461751;-0.3014631122999046	147.11279296875;276.15557861328125;486.2920494008088;557.3286316164344;654.3825176155206;580.3808029138136;709.4236840442419;260.1385613625254;373.22245708896065;541.310888080279;751.4469345441024;466.2914852187461;579.3737182617188;185.1284637451172;353.21832275163706;563.3547853826793;692.3979615356445	17	0.42104908098803717	0.1328125	0	0	None	Unknown		80.24471390221916;46.79620166286604	ALPAPIEK;QLKPLEK	_ALPAPIEK_;_(Gln->pyro-Glu)QLKPLEK_				12	17;19	5	5	7			0.07075587874123812
20220225_L1_UM8_Peng0013_SA_mab_A_1_tryp	6425	3321	ALPAPIEK	8	0	Unmodified	_ALPAPIEK_					0	0	0	0	IGHG1;IGHG3	2	CID	FTMS	MULTI-MSMS	8	0	419.75528	837.496	0.084003	3.5261E-05	1.7230246	27.907	0.00099322	89.046	59.897	NaN	NaN	1	0	0	0	6417	9356928	0.0036298454422029752	29	-1.5782909393310547	y1;y2;y3;y4;y5;y6;y7;y2-H2O;y4-H2O;y5-H2O;y6-H2O;y1-NH3;a2;b2;b3;b4	62618.0859375;151255.4375;47044.421875;607647.625;154799.203125;1090303.625;5473.419921875;162793.28125;23470.3359375;14723.6533203125;10281.857421875;38887.9765625;430963.75;88103.578125;12990.080078125;4095.277587890625	-8.035088438873572E-05;-0.00035545071847309373;-0.00048410075947913356;-0.0005210165280118417;-0.00032413841609013616;-0.0005649734587223065;0.0013966354484864496;-0.000282450743895879;-0.0006634367437072797;-0.0004684157252086152;0.0009177420350852117;-3.3383048446467E-05;-5.1085542168038955E-05;-0.00013158062967022488;-0.0005463671046754826;-0.0005401957125172885	-0.5461852280994549;-1.2871385621167437;-1.2437078086792293;-1.0714050994456952;-0.5815918972095954;-0.8633686168634294;1.8198039870073444;-1.0941549053201856;-1.4167452195361876;-0.8685314526071193;1.4421502278612206;-0.2566223453961236;-0.32510898491553686;-0.7107526322348118;-1.9362239999202124;-1.5293512188379221	147.11288452148438;276.15575271751845;389.23994534795946;486.292746115728;557.329663025416;654.3826677124587;767.4647700839514;258.14511503124385;468.2823238496437;539.3192426164252;636.3706203106649;130.08628845214844;157.1335906982422;185.1285858154297;282.1817644539047;353.2188720703125	16	0.6130887653280783	0.06779661016949153	0	0	None	Unknown		89.04619015745013;29.14901445994254	ALPAPIEK;QLKPLEK	_ALPAPIEK_;_(Gln->pyro-Glu)QLKPLEK_				13	17;19	5	5	7			0.07075587874123812
20220225_L1_UM8_Peng0013_SA_mab_A_1_tryp	4851	1890	AMKPWIQPK	9	1	Oxidation (M)	_AM(Oxidation (M))KPWIQPK_	AM(1)KPWIQPK		AM(76)KPWIQPK		0	0	1	0	CON__P02663	3	ETHCD	FTMS	MULTI-MSMS	7	0	372.20744	1113.6005	0.20657	7.6888E-05	1.2434559	20.24	0.0020528	76.064	74.177	76.064	1	1	0	0	0	4844	14932849	0.5668792127735999	-1	0.051662445068359375	y1;y2;y3;y4;y5;y6;y7;c2;c4;c5;c6;c8;z°3;z°4;z°7;z'8	3729.110595703125;20935.962890625;6237.0693359375;10659.00390625;15703.4716796875;114229.8359375;56682.9453125;7145.84619140625;39636.015625;43684.50390625;482978.40625;148973.453125;40262.0234375;50055.984375;760855.6875;32248.0625	-0.00011086846251373572;-0.0004628611890780121;0.00021497316777185915;-0.0005957519908292852;-0.001161895422114867;-0.0016740000626214169;-0.0018525730076817126;-0.0003356101359202057;-0.0011111784478430309;-0.0008324869525040413;-0.0011244188509635933;-0.0027715777140429054;-2.041069376446103E-05;-0.0016555533611608553;-0.0018746933109241581;0.00041333176523039583	-0.753628343808544;-1.8956821610386545;0.5775372030700919;-1.227573009935954;-1.7305853511914526;-2.1784339599628315;-2.066365132835774;-1.42143434557877;-2.4090319288247612;-1.2860234149433922;-1.47868410905003;-2.8122668412356533;-0.05730034234459209;-3.5277745870907817;-2.1290790868266973;0.4018550517063187	147.1129150390625;244.16603088378906;372.22393056083223;485.30880526639083;671.388684363322;768.4419603199625;896.5371019106076;236.10667419433594;461.2551766323478;647.3342108943525;760.4185668066509;985.531555328914;356.20544187529373;469.29114099836113;880.5183999615109;1028.5593361968347	16	0.19905655632954763	0.07920792079207921	0	0	None	Unknown		76.06406123404466;36.42448247123975;1.8869224993972666	AMKPWIQPK;AMKPWIQPK;KDAGGRQVQR	_AM(Oxidation (M))KPWIQPK_;_AMKPW(oxidation(w))IQPK_;_KDAGGRQVQR_				14	3	6	6	8	1		0.048229663591882854
20220225_L1_UM8_Peng0013_SA_mab_A_1_tryp	4852	1891	AMKPWIQPK	9	1	Oxidation (M)	_AM(Oxidation (M))KPWIQPK_	AM(1)KPWIQPK		AM(88)KPWIQPK		0	0	1	0	CON__P02663	3	CID	FTMS	MULTI-MSMS	8	0	372.20744	1113.6005	0.20657	7.6888E-05	1.2434559	20.247	0.00055813	88.37	88.37	88.37	1	1	0	0	0	4844	14932849	0.5668792127735999	-1	0.051662445068359375	y1;y2;y3;y4;y5;y6;y7;y8;y1-NH3;y2-NH3;y3-NH3;y6-NH3;y7-NH3;y8-NH3;a2;b2;b5;b6;b7;b7-NH3	109192.984375;368988.28125;47378.9921875;109783.0546875;87598.0234375;616023.375;134511.953125;143007.0625;66646.1328125;11889.484375;295155.46875;21663.109375;29962.380859375;3487.88916015625;2216.5;25756.98046875;41020.140625;10225.8466796875;6808.6474609375;859.0084228515625	-0.00021767998595123572;-0.0004323436109530121;-0.0007801447204087708;-0.0008664983787980418;-0.0007587105810671346;-0.0007770464154646106;-0.0019175546244696307;-0.0016905316640531964;-0.000155453360946467;-0.0004769285093857434;-0.0005883557936385841;-0.0028672347871179227;-0.0037370799709606217;-0.005261922693080123;0.002614728764058327;-0.000471747768727937;-0.0010129105439773411;-0.0006271126214869582;-0.0021714837839681422;-0.004812678800021786	-1.4796785710262992;-1.770695388811563;-2.095895966628896;-1.7854567771883703;-1.1300622938121259;-1.0111984542582846;-2.1388456555757562;-1.6199467930657252;-1.1950007715804116;-2.0997163333563136;-1.656415541620118;-3.815772462473646;-4.249035957200029;-5.125835046032383;13.683786041960738;-2.153310234698261;-1.6070092677500174;-0.8435832320907222;-2.4918006675426523;-5.632634108655406	147.11302185058594;244.16600036621094;372.2249256787204;485.3090760127788;671.388281178481;768.4410633663153;896.5371668922244;1043.572339097564;130.08641052246094;227.13949584960938;355.19818478829364;751.416604453187;879.5124373160709;1026.549361387093;191.08226013183594;219.08026123046875;630.307842216444;743.3915203989214;871.4516422814839;854.427734375	20	0.24694797591945428	0.04405286343612335	0	0	None	Unknown		88.36965876740499;46.446666962778366;0	AMKPWIQPK;AMKPWIQPK;QRELERQR	_AM(Oxidation (M))KPWIQPK_;_AMKPW(oxidation(w))IQPK_;_QRELERQR_				15	3	6	6	8	1		0.048229663591882854
20220225_L1_UM8_Peng0013_SA_mab_A_1_tryp	6497	3386	AMKPWIQPK	9	1	Unmodified	_AMKPWIQPK_					0	0	0	0	CON__P02663	3	ETHCD	FTMS	MULTI-MSMS	3	0	366.8758	1097.6056	-0.70904	-0.00026013	1.0926832	28.262	0.019498	60.892	58.04	NaN	NaN	1	0	0	0	6494	2753523	1	0	0	y1;y2;y5;y6;y7;c4;c5;c6;c8;z°3;z°4;z°7;z'7;z'8	1976.5899658203125;2730.24462890625;3133.66796875;27052.400390625;7708.90966796875;2560.681884765625;3309.382080078125;69323.6640625;20002.701171875;7566.33154296875;6120.1962890625;23507.57421875;47273.5703125;7608.4423828125	0.0003316364202987643;0.0003611134202969879;-1.8421330651108292E-05;-0.0006675404857787726;-0.0010136373374507457;5.659351876374785E-05;-0.0008871804368482117;0.0001625600806391958;-0.003088185132128274;-3.59150384952045E-05;-0.0007837139268076498;4.577601248456631E-05;0.0017083390893049;0.0010119486735220562	2.2543052576436904;1.4789716555778913;-0.02743770107307897;-0.8686945723354234;-1.130614989389539;0.1271024432652278;-1.4052354498276147;0.21837076401418237;-3.1852165189071555;-0.10082674970621461;-1.6699982469532997;0.05198768399083945;1.9379412484564082;0.999392483296536	147.1124725341797;244.1652069091797;671.3875408892305;768.4409538603857;896.5362629749374;445.25909423828125;631.3393509657369;744.4223652056194;969.5369573142322;356.20545737963846;469.2902691589268;880.5164794921875;881.5226419612106;1012.5638229578265	14	0.1942208177331933	0.0880503144654088	0	0	None	Unknown		60.89180140430557;2.8518191005973565	AMKPWIQPK;QESLELIRK	_AMKPWIQPK_;_(Gln->pyro-Glu)QESLELIRK_				16	3	6	7	9			0.06067270221819854
20220225_L1_UM8_Peng0013_SA_mab_A_1_tryp	6499	3388	AMKPWIQPK	9	1	Unmodified	_AMKPWIQPK_					0	0	0	0	CON__P02663	3	CID	FTMS	MULTI-MSMS	5	0	366.8758	1097.6056	-0.70904	-0.00026013	1.0926832	28.274	0.00059441	88.37	86.334	NaN	NaN	1	0	0	0	6494	2753523	1	0	0	y1;y2;y3;y4;y5;y6;y7;y8;y1-NH3;y2-NH3;y3-NH3;y5-NH3;y6-NH3;y7-NH3;a2;b2;b4;b5;b6;b7(2+)	15274.078125;36969.87890625;7032.0341796875;13885.4453125;17214.212890625;129998.203125;22643.21875;4551.54931640625;13168.87890625;1289.09716796875;29024.859375;1013.5811767578125;2346.6923828125;3783.072998046875;12648.0966796875;1824.768310546875;4553.384765625;4629.75537109375;713.0250854492188;4553.384765625	0.00010275458436126428;4.06788499844879E-05;-0.00022764139640685244;6.14274542840576E-05;0.0005343120318457295;0.0005686528247679234;0.0005743620316707165;0.0025009040712120623;0.000134463631241033;2.6611529676756618E-05;8.521558771690252E-05;-0.007312766412610472;-0.0013628792563622483;-0.005177456190040175;0.00011648849999801314;2.0734623461748924E-05;0.0032926482687685166;0.00032599034841496177;0.004377101700015373;0.0016072390687895677	0.6984752735298337;0.1666035759717133;-0.6115703667249786;0.12657412517428518;0.7958331651814565;0.7400096737507406;0.6406467565645118;2.433796434940195;1.0336508661738062;0.11715967129275393;0.2399104301855961;-11.175306883876477;-1.8137501577824617;-5.886724838981539;0.6653070075517338;0.1020983251113691;7.68898391337754;0.5306596105541396;6.017531259108548;3.7532206103195196	147.11270141601562;244.16552734375;372.2243731753964;485.3081480869457;671.386988155868;768.4397176670751;896.5346749755682;1027.5732330397288;130.08612060546875;227.1389923095703;355.1975112169123;654.3682861328125;751.4151000976562;879.51387769229;175.08984375;203.08485412597656;428.22930908203125;614.3115886934517;727.3916015625;428.22930908203125	20	0.2678539567186284	0.06884057971014493	0	0	None	Unknown		88.36965876740499;2.0357826168845694	AMKPWIQPK;QESLELIRK	_AMKPWIQPK_;_(Gln->pyro-Glu)QESLELIRK_				17	3	6	7	9			0.06067270221819854
20220225_L1_UM8_Peng0013_SA_mab_A_1_tryp	4423	1501	AQYEEIANR	9	0	Unmodified	_AQYEEIANR_					0	0	0	0	CON__P13647	2	ETHCD	FTMS	MULTI-MSMS	8	0	547.26727	1092.52	0.38385	0.00021007	2.9840251	18.151	0.0030574	101.64	54.457	NaN	NaN	1	0	0	0	4415	6947319	0.2999219556621128	1	-0.055812835693359375	y1;y3;y4;y5;y6;y7;c8;z°3;z°4;z°5;z°6;z°7;z°8;z'2	951.2175903320312;1620.69384765625;2248.073486328125;3184.73095703125;5610.0224609375;29416.81640625;4918.42724609375;7124.21240234375;15928.6630859375;29674.12109375;15365.568359375;6655.4052734375;12492.44921875;2971.8740234375	9.92025780988115E-06;-0.0010493086093106285;3.7376868817773357E-05;-0.0009031414699620655;-0.000267138044478088;-0.0001872590358971138;0.0012115104174199587;-0.001802254228948641;-0.000927774521471747;-0.001022136310893984;-0.0006786258413740143;-0.0011767274172598263;-0.0005790530335616495;-0.0002645262874807486	0.05664868506977645;-2.913127387141585;0.07897361037002955;-1.4994216418204749;-0.3652577880507904;-0.20936089749947268;1.2937392895638113;-5.236339651760932;-2.0289634931741807;-1.7433437725093983;-0.9486624077739183;-1.3396045418875049;-0.5753294983888272;-0.9648917967440759	175.1189422607422;360.2000427246094;473.28302001953125;602.3265536340699;731.3685107268444;894.4317593861358;936.4409253029826;344.182071600829;457.2652611015215;586.3079485595109;715.3501981452414;878.4140247851172;1006.4720046221336;274.1512451171875	14	0.2324769183073939	0.15730337078651685	0	0	None	Unknown		101.64353485380936;47.18689753183167;6.303046881789662	AQYEEIANR;AQYEDIAQR;AFDICPLEK	_AQYEEIANR_;_AQYEDIAQR_;_AFDICPLEK_				18	12	7	8	10			-0.022572234301378558";

const MAXQUANT_MSMS_SCANS: &str = "Raw file                                             	Scan number 	Retention time 	Ion injection time 	Total ion current  	Collision energy    	Summations 	Base peak intensity 	Elapsed time 	Identified 	Matched 	Reverse 	MS/MS IDs 	Sequence                                                                                                       	Length 	Filtered peaks 	m/z                 	Mass               	Charge 	MS2 m/z             	Type  	Fragmentation 	Mass analyzer 	Parent intensity fraction 	Fraction of total spectrum 	Base peak fraction 	Precursor full scan number 	Precursor intensity 	Precursor apex fraction 	Precursor apex offset 	Precursor apex offset time 	Scan event number 	Modifications                  	Modified sequence                                                                                                                                                	Proteins                                                                                                                                                                              	Score                  	PEP                     	Experiment        	MS3 scan numbers 	Reporter PIF 	Reporter fraction 	Intens Comp Factor 	CTCD Comp 	RawOvFtT   	AGC Fill 	Scan index 	MS scan index 	MS scan number
20230418_L1_UM1_Peng0013_SA_EXT00_mix3_lysN_4h_test2 	          3 	     0.0056511 	NaN                	    109530         	 35                 	         0 	             9009.1 	       0.341 	           	        	        	-1        	                                                                                                               	     0 	            87 	1349.6195068359375  	NaN                	     0 	1349.6195068359375  	PEAK  	CID           	FTMS          	                        0 	                         0 	                 0 	-1                         	NaN                 	NaN                     	0                     	NaN                        	                1 	                               	                                                                                                                                                                 	                                                                                                                                                                                      	NaN                    	NaN                     	LysN_sp3_L1_test2 	                 	             	                  	NaN                	NaN       	  230239.9 	NaN      	         0 	            1 	             2
20230418_L1_UM1_Peng0013_SA_EXT00_mix3_lysN_4h_test2 	          4 	     0.010648  	NaN                	     60049         	 25.448551177978516 	         0 	             8063.8 	       0.408 	           	        	        	-1        	                                                                                                               	     0 	            34 	1349.6195068359375  	NaN                	     0 	1349.6195068359375  	PEAK  	ETHCD         	FTMS          	                        0 	                         0 	                 0 	-1                         	NaN                 	NaN                     	0                     	NaN                        	                2 	                               	                                                                                                                                                                 	                                                                                                                                                                                      	NaN                    	NaN                     	LysN_sp3_L1_test2 	                 	             	                  	NaN                	NaN       	  220183.5 	NaN      	         1 	            1 	             2
20230418_L1_UM1_Peng0013_SA_EXT00_mix3_lysN_4h_test2 	          6 	     0.018001  	NaN                	    115910         	 35                 	         0 	            15149   	       0.341 	           	        	+       	-1        	KSSEDFVAFMLVHKQEFKMQTGDETLT                                                                                    	    27 	            79 	1573.7630615234375  	NaN                	     0 	1573.7630615234375  	PEAK  	CID           	FTMS          	                        0 	                         0 	                 0 	-1                         	NaN                 	NaN                     	0                     	NaN                        	                1 	Unmodified                     	_KSSEDFVAFMLVHKQEFKMQTGDETLT_                                                                                                                                    	REV__CON__Q28107                                                                                                                                                                      	0                      	0.03366231396707156     	LysN_sp3_L1_test2 	                 	             	                  	NaN                	NaN       	  234690.4 	NaN      	         2 	            2 	             5
20230418_L1_UM1_Peng0013_SA_EXT00_mix3_lysN_4h_test2 	          7 	     0.022909  	NaN                	     74998         	 35                 	         0 	            13478   	       0.339 	           	        	        	-1        	                                                                                                               	     0 	            56 	1163.2366943359375  	NaN                	     0 	1163.2366943359375  	PEAK  	CID           	FTMS          	                        0 	                         0 	                 0 	-1                         	NaN                 	NaN                     	0                     	NaN                        	                2 	                               	                                                                                                                                                                 	                                                                                                                                                                                      	NaN                    	NaN                     	LysN_sp3_L1_test2 	                 	             	                  	NaN                	NaN       	  223897.4 	NaN      	         3 	            2 	             5
20230418_L1_UM1_Peng0013_SA_EXT00_mix3_lysN_4h_test2 	          8 	     0.027606  	NaN                	    102770         	 35                 	         0 	             8106.2 	       0.338 	           	        	        	-1        	                                                                                                               	     0 	            74 	1739.9771728515625  	NaN                	     0 	1739.9771728515625  	PEAK  	CID           	FTMS          	                        0 	                         0 	                 0 	-1                         	NaN                 	NaN                     	0                     	NaN                        	                3 	                               	                                                                                                                                                                 	                                                                                                                                                                                      	NaN                    	NaN                     	LysN_sp3_L1_test2 	                 	             	                  	NaN                	NaN       	  227018.9 	NaN      	         4 	            2 	             5
20230418_L1_UM1_Peng0013_SA_EXT00_mix3_lysN_4h_test2 	         10 	     0.033801  	NaN                	    294490         	 35                 	         0 	            15932   	       0.341 	           	        	        	-1        	                                                                                                               	     0 	           117 	1734.0943504131785  	NaN                	     0 	1733.8475341796875  	PEAK  	CID           	FTMS          	                        0 	                         0 	                 0 	9                          	276228.03125        	0.7433725255247668      	2                     	-0.027422990649938583      	                1 	                               	                                                                                                                                                                 	                                                                                                                                                                                      	NaN                    	NaN                     	LysN_sp3_L1_test2 	                 	             	                  	NaN                	NaN       	  285364.1 	NaN      	         5 	            3 	             9
20230418_L1_UM1_Peng0013_SA_EXT00_mix3_lysN_4h_test2 	         11 	     0.039586  	NaN                	    140950         	  6.362137794494629 	         0 	             9751.4 	       0.412 	           	        	        	-1        	                                                                                                               	     0 	           102 	1734.0943504131785  	NaN                	     0 	1733.8475341796875  	PEAK  	ETHCD         	FTMS          	                        0 	                         0 	                 0 	9                          	276228.03125        	0.7433725255247668      	2                     	-0.027422990649938583      	                2 	                               	                                                                                                                                                                 	                                                                                                                                                                                      	NaN                    	NaN                     	LysN_sp3_L1_test2 	                 	             	                  	NaN                	NaN       	  229074.2 	NaN      	         6 	            3 	             9
20230418_L1_UM1_Peng0013_SA_EXT00_mix3_lysN_4h_test2 	         13 	     0.047435  	NaN                	    148880         	 35                 	         0 	            12742   	       0.341 	           	        	        	-1        	KSLLAPLNVELDPEIQKVRAQEREQIKVLNN                                                                                	    31 	            86 	1793.0023846579024  	NaN                	     0 	1793.008544921875   	PEAK  	CID           	FTMS          	                        0 	                         0 	                 0 	12                         	66956.421875        	0.3254467704662902      	1                     	-0.013797469437122345      	                1 	Unmodified                     	_KSLLAPLNVELDPEIQKVRAQEREQIKVLNN_                                                                                                                                	CON__Q32MB2                                                                                                                                                                           	0                      	0.03483424884993438     	LysN_sp3_L1_test2 	                 	             	                  	NaN                	NaN       	  248185.3 	NaN      	         7 	            4 	            12
20230418_L1_UM1_Peng0013_SA_EXT00_mix3_lysN_4h_test2 	         14 	     0.053251  	NaN                	     98596         	  6.362137794494629 	         0 	             9833.9 	       0.412 	           	        	        	-1        	KSLLAPLNVELDPEIQKVRAQEREQIKVLNN                                                                                	    31 	            75 	1793.0023846579024  	NaN                	     0 	1793.008544921875   	PEAK  	ETHCD         	FTMS          	                        0 	                         0 	                 0 	12                         	66956.421875        	0.3254467704662902      	1                     	-0.013797469437122345      	                2 	Unmodified                     	_KSLLAPLNVELDPEIQKVRAQEREQIKVLNN_                                                                                                                                	CON__Q32MB2                                                                                                                                                                           	0                      	0.02816765529174602     	LysN_sp3_L1_test2 	                 	             	                  	NaN                	NaN       	  233272   	NaN      	         8 	            4 	            12
20230418_L1_UM1_Peng0013_SA_EXT00_mix3_lysN_4h_test2 	         17 	     0.065153  	NaN                	    256780         	 35                 	         0 	            25486   	       0.342 	           	        	+       	-1        	KEQIKHQEVSNPVIEESSSISEAEMKQIDEMAQDETSESGIKDSLEN                                                                	    47 	           121 	1759.4891615834924  	NaN                	     0 	1759.736328125      	PEAK  	CID           	FTMS          	                        0 	                         0 	                 0 	-1                         	NaN                 	NaN                     	0                     	NaN                        	                1 	Unmodified                     	_KEQIKHQEVSNPVIEESSSISEAEMKQIDEMAQDETSESGIKDSLEN_                                                                                                                	REV__CON__P02662                                                                                                                                                                      	3.0973716062068755E-11 	0.03636947474328521     	LysN_sp3_L1_test2 	                 	             	                  	NaN                	NaN       	  260158.6 	NaN      	         9 	            6 	            16
20230418_L1_UM1_Peng0013_SA_EXT00_mix3_lysN_4h_test2 	         18 	     0.070984  	NaN                	    109430         	  6.362137794494629 	         0 	             9619.7 	       0.412 	+          	        	        	183       	KKRTTVLVKNEESLVFVQTDKPIYKPEQTV                                                                                 	    30 	            74 	1759.4891615834924  	NaN                	     0 	1759.736328125      	PEAK  	ETHCD         	FTMS          	                        0 	                         0 	                 0 	-1                         	NaN                 	NaN                     	0                     	NaN                        	                2 	Unmodified                     	_KKRTTVLVKNEESLVFVQTDKPIYKPEQTV_                                                                                                                                 	CON__ENSEMBL:ENSBTAP00000024146                                                                                                                                                       	0.0030724080800320383  	0.022949660202820587    	LysN_sp3_L1_test2 	                 	             	                  	NaN                	NaN       	  217612   	NaN      	        10 	            6 	            16
20230418_L1_UM1_Peng0013_SA_EXT00_mix3_lysN_4h_test2 	         20 	     0.078902  	NaN                	    230230         	 35                 	         0 	            20622   	       0.341 	           	        	        	-1        	KQEIAEINRMIQRLRSEIDHVKKQCASLQAAIADAEQRGEMALKDA                                                                 	    46 	           105 	1760.2404015806294  	NaN                	     0 	1759.9840087890625  	PEAK  	CID           	FTMS          	                        0 	                         0 	                 0 	-1                         	NaN                 	NaN                     	0                     	NaN                        	                1 	Oxidation (M)                  	_KQEIAEINRM(Oxidation (M))IQRLRSEIDHVKKQCASLQAAIADAEQRGEMALKDA_                                                                                                  	CON__P48668                                                                                                                                                                           	2.7558068175513996E-11 	0.03670385943504501     	LysN_sp3_L1_test2 	                 	             	                  	NaN                	NaN       	  259568.4 	NaN      	        11 	            7 	            19
20230418_L1_UM1_Peng0013_SA_EXT00_mix3_lysN_4h_test2 	         21 	     0.084718  	NaN                	     91846         	  6.362137794494629 	         0 	            13332   	       0.412 	           	        	        	-1        	KQEIAEINRMIQRLRSEIDHVKKQCASLQAAIADAEQRGEMALKDA                                                                 	    46 	            65 	1760.2404015806294  	NaN                	     0 	1759.9840087890625  	PEAK  	ETHCD         	FTMS          	                        0 	                         0 	                 0 	-1                         	NaN                 	NaN                     	0                     	NaN                        	                2 	Oxidation (M)                  	_KQEIAEINRMIQRLRSEIDHVKKQCASLQAAIADAEQRGEM(Oxidation (M))ALKDA_                                                                                                  	CON__P48668                                                                                                                                                                           	0.47794882249273646    	0.026411218974289115    	LysN_sp3_L1_test2 	                 	             	                  	NaN                	NaN       	  225244.5 	NaN      	        12 	            7 	            19
20230418_L1_UM1_Peng0013_SA_EXT00_mix3_lysN_4h_test2 	         22 	     0.091432  	NaN                	    136260         	 35                 	         0 	            19732   	       0.339 	           	        	        	-1        	                                                                                                               	     0 	            86 	1563.9946204546777  	NaN                	     0 	1564.2078857421875  	PEAK  	CID           	FTMS          	                        0 	                         0 	                 0 	19                         	73966.765625        	0.6617400609994206      	-1                    	0.01366424560546875        	                3 	                               	                                                                                                                                                                 	                                                                                                                                                                                      	NaN                    	NaN                     	LysN_sp3_L1_test2 	                 	             	                  	NaN                	NaN       	  235277.9 	NaN      	        13 	            7 	            19
20230418_L1_UM1_Peng0013_SA_EXT00_mix3_lysN_4h_test2 	         23 	     0.096127  	NaN                	    108090         	 35                 	         0 	             9893.7 	       0.338 	           	        	        	-1        	KLSSFKADVRAHGEGQEFMTTCLVDKEEMK                                                                                 	    30 	            64 	1736.341470735175   	NaN                	     0 	1736.3251953125     	PEAK  	CID           	FTMS          	                        0 	                         0 	                 0 	19                         	85466.1953125       	0.5463427353371759      	-1                    	0.01366424560546875        	                4 	Unmodified                     	_KLSSFKADVRAHGEGQEFMTTCLVDKEEMK_                                                                                                                                 	CON__Q0VCM5                                                                                                                                                                           	0                      	0.03422635933570534     	LysN_sp3_L1_test2 	                 	             	                  	NaN                	NaN       	  241494.7 	NaN      	        14 	            7 	            19
20230418_L1_UM1_Peng0013_SA_EXT00_mix3_lysN_4h_test2 	         24 	     0.10075   	NaN                	     65778         	 35                 	         0 	            16616   	       0.338 	           	        	        	-1        	                                                                                                               	     0 	            44 	1162.9739990234375  	NaN                	     0 	1162.9739990234375  	PEAK  	CID           	FTMS          	                        0 	                         0 	                 0 	-1                         	NaN                 	NaN                     	0                     	NaN                        	                5 	                               	                                                                                                                                                                 	                                                                                                                                                                                      	NaN                    	NaN                     	LysN_sp3_L1_test2 	                 	             	                  	NaN                	NaN       	  216144   	NaN      	        15 	            7 	            19
20230418_L1_UM1_Peng0013_SA_EXT00_mix3_lysN_4h_test2 	         25 	     0.10537   	NaN                	     86756         	 35                 	         0 	            16367   	       0.338 	           	        	        	-1        	KIEGSSNHLVTFTVLPLEVGLHNLSFSLETSVGNEILV                                                                         	    38 	            54 	1365.0689697265625  	NaN                	     0 	1365.0689697265625  	PEAK  	CID           	FTMS          	                        0 	                         0 	                 0 	-1                         	NaN                 	NaN                     	0                     	NaN                        	                6 	Unmodified                     	_KIEGSSNHLVTFTVLPLEVGLHNLSFSLETSVGNEILV_                                                                                                                         	CON__Q1A7A4                                                                                                                                                                           	1.6731081544702753E-12 	0.03909349133594582     	LysN_sp3_L1_test2 	                 	             	                  	NaN                	NaN       	  219080.7 	NaN      	        16 	            7 	            19
20230418_L1_UM1_Peng0013_SA_EXT00_mix3_lysN_4h_test2 	         26 	     0.10998   	NaN                	     99046         	 35                 	         0 	             8872.6 	       0.338 	           	        	        	-1        	                                                                                                               	     0 	            74 	1764.98681640625    	NaN                	     0 	1764.98681640625    	PEAK  	CID           	FTMS          	                        0 	                         0 	                 0 	-1                         	NaN                 	NaN                     	0                     	NaN                        	                7 	                               	                                                                                                                                                                 	                                                                                                                                                                                      	NaN                    	NaN                     	LysN_sp3_L1_test2 	                 	             	                  	NaN                	NaN       	  238263.3 	NaN      	        17 	            7 	            19
20230418_L1_UM1_Peng0013_SA_EXT00_mix3_lysN_4h_test2 	         28 	     0.11617   	NaN                	    147010         	 35                 	         0 	             6579.6 	       0.341 	           	        	        	-1        	                                                                                                               	     0 	           101 	1766.4884580021653  	7061.9247261422615 	     4 	1767.747314453125   	MULTI 	CID           	FTMS          	                        0 	                         0 	                 0 	27                         	165744.078125       	0.49159822680931803     	2                     	-0.02665609121322632       	                1 	                               	                                                                                                                                                                 	                                                                                                                                                                                      	NaN                    	NaN                     	LysN_sp3_L1_test2 	                 	             	                  	NaN                	NaN       	  246445.1 	NaN      	        18 	            8 	            27";

const MAXQUANT_NOVO_MSMS_SCANS: &str = "Raw file                                           	Scan number 	Retention time 	Ion injection time 	Total ion current 	Collision energy    	Summations 	Base peak intensity 	Elapsed time 	Identified 	Matched 	Reverse 	MS/MS IDs 	Sequence                                 	Length 	Filtered peaks 	m/z                 	Mass               	Charge 	MS2 m/z             	Type  	Fragmentation 	Mass analyzer 	Parent intensity fraction 	Fraction of total spectrum 	Base peak fraction 	Precursor full scan number 	Precursor intensity 	Precursor apex fraction 	Precursor apex offset 	Precursor apex offset time 	Scan event number 	Modifications                 	Modified sequence                                                                           	Proteins                                                                                                                          	Score                  	PEP                     	Experiment  	MS3 scan numbers 	Reporter PIF 	Reporter fraction 	DN sequence                                                                                                                                                                            	DN length 	DN min levenshtein distance 	DN extension sequence                                                      	DN extended 	DN complete 	DN raw score 	DN extension score 	DN extension norm. score 	DN normalized score 	DN complete score 	DN combined score 	DN nterm mass      	DN cterm mass      	DN missing mass    	DN nterm delta score  	DN cterm delta score  	DN term delta score   	DN full length delta score 	DN protease score 	DN complement score  	DN A2 score           	DN water loss score   	DN ammonia loss score 	DN agrees with andromeda 	DN agrees with andromeda complete 	DN all sequences                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            	DN all scores                                                             	DN all agrees       	DN any agrees 	DN number of steps 	DN is dominantly y 	Intens Comp Factor 	CTCD Comp 	RawOvFtT  	AGC Fill 	Scan index 	MS scan index 	MS scan number
20221121_F1_UM4_Peng0013_SA_EXT00_MIX3_SP3_LysN_1h 	        142 	       0.72822 	NaN                	           288190 	35                  	         0 	            40942   	       0.345 	           	        	        	-1        	                                         	     0 	            44 	 612.1839599609375  	NaN                	     0 	 612.1839599609375  	PEAK  	CID           	FTMS          	                        0 	                         0 	                 0 	-1                         	NaN                 	NaN                     	0                     	NaN                        	                1 	                              	                                                                                            	                                                                                                                                  	NaN                    	NaN                     	sp3_lysn_1h 	                 	             	                  	A                                                                                                                                                                                      	1         	-1                          	                                                                           	            	            	    2.4743   	0                  	0                        	          0.20308   	           0      	            0     	980.2683953351578  	164.02427087955314 	1144.292666214711  	0                     	0                     	0                     	     0                     	                0 	0                    	0                     	 0                    	 0                    	                         	                                  	A                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           	0.20308                                                                   	-                   	              	                 3 	+                  	NaN                	NaN       	 102970.2 	NaN      	         0 	          140 	           141
20221121_F1_UM4_Peng0013_SA_EXT00_MIX3_SP3_LysN_1h 	        143 	       0.73405 	NaN                	           206420 	86.43135070800781   	         0 	            28810   	       0.499 	           	        	        	-1        	                                         	     0 	            71 	 612.1839599609375  	NaN                	     0 	 612.1839599609375  	PEAK  	ETHCD         	FTMS          	                        0 	                         0 	                 0 	-1                         	NaN                 	NaN                     	0                     	NaN                        	                2 	                              	                                                                                            	                                                                                                                                  	NaN                    	NaN                     	sp3_lysn_1h 	                 	             	                  	                                                                                                                                                                                       	-1        	-1                          	                                                                           	            	            	    0        	0                  	0                        	          0         	           0      	            0     	NaN                	NaN                	NaN                	0                     	0                     	0                     	     0                     	                0 	0                    	0                     	 0                    	 0                    	                         	                                  	                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                            	0                                                                         	-                   	              	                 0 	                   	NaN                	NaN       	  76652.4 	NaN      	         1 	          140 	           141
20221121_F1_UM4_Peng0013_SA_EXT00_MIX3_SP3_LysN_1h 	       1591 	       8.0177  	NaN                	           154180 	35                  	         0 	            23985   	       0.346 	           	        	        	-1        	                                         	     0 	            62 	 368.68696927490356 	NaN                	     0 	 368.687255859375   	PEAK  	CID           	FTMS          	                        0 	                         0 	                 0 	1590                       	157140.3125         	0.768202274775432       	-108                  	0.5617332458496094         	                1 	                              	                                                                                            	                                                                                                                                  	NaN                    	NaN                     	sp3_lysn_1h 	                 	             	                  	C                                                                                                                                                                                      	1         	-1                          	                                                                           	            	            	    7.4743   	0                  	0                        	          1.0164    	           0      	            0     	446.25032907539463 	125.07152734927969 	571.3218564246744  	0                     	0                     	0                     	     0                     	                0 	0.5                  	0                     	 0                    	 0                    	                         	                                  	C                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           	1.0164                                                                    	-                   	              	                10 	+                  	NaN                	NaN       	  67962.1 	NaN      	         2 	         1587 	          1590
20221121_F1_UM4_Peng0013_SA_EXT00_MIX3_SP3_LysN_1h 	       1592 	       8.0235  	NaN                	           138260 	86.43135070800781   	         0 	            13394   	       0.499 	           	        	        	-1        	                                         	     0 	            69 	 368.68696927490356 	NaN                	     0 	 368.687255859375   	PEAK  	ETHCD         	FTMS          	                        0 	                         0 	                 0 	1590                       	157140.3125         	0.768202274775432       	-108                  	0.5617332458496094         	                2 	                              	                                                                                            	                                                                                                                                  	NaN                    	NaN                     	sp3_lysn_1h 	                 	             	                  	SV                                                                                                                                                                                     	2         	-1                          	                                                                           	            	            	   10.969    	0                  	0                        	          1.4917    	           0      	            0     	115.0248153884723  	431.2104586236938  	546.2352740121661  	0                     	0                     	0                     	     0                     	                0 	0                    	0                     	 0                    	 0                    	                         	                                  	SV                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          	1.4917                                                                    	-                   	              	                 3 	+                  	NaN                	NaN       	  63133   	NaN      	         3 	         1587 	          1590
20221121_F1_UM4_Peng0013_SA_EXT00_MIX3_SP3_LysN_1h 	       1664 	       8.3987  	NaN                	           146750 	35                  	         0 	            21485   	       0.346 	           	        	        	-1        	                                         	     0 	            57 	 368.68696927490356 	NaN                	     0 	 368.6874694824219  	PEAK  	CID           	FTMS          	                        0 	                         0 	                 0 	1663                       	175349.171875       	0.8572188165551929      	-37                   	0.1924457550048828         	                1 	                              	                                                                                            	                                                                                                                                  	NaN                    	NaN                     	sp3_lysn_1h 	                 	             	                  	C                                                                                                                                                                                      	1         	-1                          	                                                                           	            	            	   14.124    	0                  	0                        	          1.9207    	           0      	            0     	128.09561111991007 	443.2244967096313  	571.3201078295414  	0                     	0                     	0                     	     0                     	                0 	0.7134679910804405   	0                     	 0                    	 0                    	                         	                                  	C                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           	1.9207                                                                    	-                   	              	                 6 	+                  	NaN                	NaN       	  66493.8 	NaN      	         4 	         1658 	          1663
20221121_F1_UM4_Peng0013_SA_EXT00_MIX3_SP3_LysN_1h 	       1665 	       8.4045  	NaN                	           141010 	86.43135070800781   	         0 	            12527   	       0.499 	           	        	        	-1        	                                         	     0 	            67 	 368.68696927490356 	NaN                	     0 	 368.6874694824219  	PEAK  	ETHCD         	FTMS          	                        0 	                         0 	                 0 	1663                       	175349.171875       	0.8572188165551929      	-37                   	0.1924457550048828         	                2 	                              	                                                                                            	                                                                                                                                  	NaN                    	NaN                     	sp3_lysn_1h 	                 	             	                  	SV                                                                                                                                                                                     	2         	-1                          	                                                                           	            	            	   10.969    	0                  	0                        	          1.4917    	           0      	            0     	115.02354689522743 	431.2099665064587  	546.2335134016862  	0                     	0                     	0                     	     0                     	                0 	0                    	0                     	 0                    	 0                    	                         	                                  	SV                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          	1.4917                                                                    	-                   	              	                 4 	+                  	NaN                	NaN       	  65778.3 	NaN      	         5 	         1658 	          1663
20221121_F1_UM4_Peng0013_SA_EXT00_MIX3_SP3_LysN_1h 	       2131 	      10.842   	NaN                	           148540 	35                  	         0 	            18447   	       0.346 	           	        	        	-1        	                                         	     0 	            57 	 368.6869691005552  	NaN                	     0 	 368.6872253417969  	PEAK  	CID           	FTMS          	                        0 	                         0 	                 0 	2130                       	132219.796875       	0.6562021272660682      	1                     	-0.01580524444580078       	                1 	                              	                                                                                            	                                                                                                                                  	NaN                    	NaN                     	sp3_lysn_1h 	                 	             	                  	C                                                                                                                                                                                      	1         	-1                          	                                                                           	            	            	    5.4846   	0                  	0                        	          0.74583   	           0      	            0     	446.2502371739635  	125.07158838443594 	571.3218255583995  	0                     	0                     	0                     	     0                     	                0 	0.5                  	0                     	 0                    	 0                    	                         	                                  	C                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           	0.74583                                                                   	-                   	              	                 5 	+                  	NaN                	NaN       	  64707.7 	NaN      	         6 	         2123 	          2130
20221121_F1_UM4_Peng0013_SA_EXT00_MIX3_SP3_LysN_1h 	       2132 	      10.848   	NaN                	           141900 	86.43135070800781   	         0 	            13729   	       0.499 	           	        	        	-1        	                                         	     0 	            79 	 368.6869691005552  	NaN                	     0 	 368.6872253417969  	PEAK  	ETHCD         	FTMS          	                        0 	                         0 	                 0 	2130                       	132219.796875       	0.6562021272660682      	1                     	-0.01580524444580078       	                2 	                              	                                                                                            	                                                                                                                                  	NaN                    	NaN                     	sp3_lysn_1h 	                 	             	                  	GSV                                                                                                                                                                                    	3         	-1                          	                                                                           	            	            	   16.198    	0                  	0                        	          2.2027    	           0      	            0     	58.01051835895232  	431.2109774225219  	489.22149578147423 	0                     	0                     	0                     	     0                     	                0 	0                    	0                     	 0                    	 0                    	                         	                                  	GSV                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         	2.2027                                                                    	-                   	              	                 7 	+                  	NaN                	NaN       	  64388.9 	NaN      	         7 	         2123 	          2130
20221121_F1_UM4_Peng0013_SA_EXT00_MIX3_SP3_LysN_1h 	       2273 	      11.571   	NaN                	           168290 	35                  	         0 	            22781   	       0.346 	           	        	        	-1        	                                         	     0 	            59 	 368.6867934807561  	735.3590340283122  	     2 	 368.6873474121094  	MULTI 	CID           	FTMS          	                        0 	                         0 	                 0 	2272                       	153648.03125        	0.0021594633866407883   	-78                   	0.39493370056152344        	                1 	                              	                                                                                            	                                                                                                                                  	NaN                    	NaN                     	sp3_lysn_1h 	                 	             	                  	KC                                                                                                                                                                                     	2         	-1                          	                                                                           	            	            	   41.098    	0                  	0                        	          5.5889    	           0      	            0     	0                  	443.2262056940063  	443.2262056940063  	6.4943663581923445    	0                     	0                     	     0                     	                2 	0.6747425010840047   	0                     	 0                    	 0                    	                         	                                  	KC                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          	5.5889                                                                    	-                   	              	                34 	+                  	NaN                	NaN       	  67513   	NaN      	         8 	         2263 	          2272
20221121_F1_UM4_Peng0013_SA_EXT00_MIX3_SP3_LysN_1h 	       2274 	      11.577   	NaN                	           155530 	86.43135070800781   	         0 	            13132   	       0.499 	           	        	        	-1        	                                         	     0 	            75 	 368.6867934807561  	735.3590340283122  	     2 	 368.6873474121094  	MULTI 	ETHCD         	FTMS          	                        0 	                         0 	                 0 	2272                       	153648.03125        	0.0021594633866407883   	-78                   	0.39493370056152344        	                2 	                              	                                                                                            	                                                                                                                                  	NaN                    	NaN                     	sp3_lysn_1h 	                 	             	                  	DSV                                                                                                                                                                                    	3         	-1                          	                                                                           	            	            	   21.965    	0                  	0                        	          2.987     	           0      	            0     	0                  	431.21064172916255 	431.21064172916255 	19.97572880015567     	0                     	0                     	     0                     	                0 	0                    	0                     	 0                    	 0                    	                         	                                  	DSV                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         	2.987                                                                     	-                   	              	                 9 	+                  	NaN                	NaN       	  70694.5 	NaN      	         9 	         2263 	          2272
20221121_F1_UM4_Peng0013_SA_EXT00_MIX3_SP3_LysN_1h 	       2329 	      11.851   	NaN                	           213330 	35                  	         0 	            21792   	       0.346 	           	        	        	-1        	                                         	     0 	            77 	 368.6867934807561  	735.3590340283122  	     2 	 368.6872863769531  	MULTI 	CID           	FTMS          	                        0 	                         0 	                 0 	2328                       	157009.421875       	0.0022067064259679524   	-24                   	0.11892414093017578        	                1 	                              	                                                                                            	                                                                                                                                  	NaN                    	NaN                     	sp3_lysn_1h 	                 	             	                  	{[CQ]|[W(Oxidation_W)S]|[CK]}VKSN                                                                                                                                                      	6         	-1                          	                                                                           	            	+           	   61.124    	0                  	0                        	          8.3121    	           8.3121 	           98.578 	0                  	0                  	0                  	4.09750390332492      	29.703912420598645    	4.09750390332492      	    61.12389570242465      	                2 	1.1549471895720984   	0                     	 0.6139829889124311   	 0.2614393726401688   	                         	                                  	{[CQ]|[W(Oxidation_W)S]|[CK]}VKSN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           	8.3121                                                                    	-                   	              	                36 	                   	NaN                	NaN       	  77712   	NaN      	        10 	         2317 	          2328
20221121_F1_UM4_Peng0013_SA_EXT00_MIX3_SP3_LysN_1h 	       2330 	      11.856   	NaN                	           178490 	86.43135070800781   	         0 	            11622   	       0.499 	           	        	        	-1        	                                         	     0 	            88 	 368.6867934807561  	735.3590340283122  	     2 	 368.6872863769531  	MULTI 	ETHCD         	FTMS          	                        0 	                         0 	                 0 	2328                       	157009.421875       	0.0022067064259679524   	-24                   	0.11892414093017578        	                2 	                              	                                                                                            	                                                                                                                                  	NaN                    	NaN                     	sp3_lysn_1h 	                 	             	                  	N                                                                                                                                                                                      	1         	-1                          	                                                                           	            	            	   30.596    	0                  	0                        	          4.1607    	           0      	            0     	603.3043750701075  	0                  	603.3043750701075  	0                     	8.630503195080184     	0                     	     0                     	                2 	0                    	0                     	 0                    	 0                    	                         	                                  	N                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           	4.1607                                                                    	-                   	              	                11 	+                  	NaN                	NaN       	  73346.1 	NaN      	        11 	         2317 	          2328
20221121_F1_UM4_Peng0013_SA_EXT00_MIX3_SP3_LysN_1h 	       2344 	      11.926   	NaN                	           234450 	35                  	         0 	            33223   	       0.347 	           	        	        	-1        	                                         	     0 	            69 	 352.68261973910853 	703.3506865450171  	     2 	 352.6827697753906  	MULTI 	CID           	FTMS          	                        0 	                         0 	                 0 	2343                       	197840.28125        	0.15698731522236797     	-11                   	0.054450035095214844       	                1 	                              	                                                                                            	                                                                                                                                  	NaN                    	NaN                     	sp3_lysn_1h 	                 	             	                  	SN                                                                                                                                                                                     	2         	-1                          	                                                                           	            	            	   35.969    	0                  	0                        	          5.114     	           0      	            0     	484.26564733778895 	0                  	484.26564733778895 	0                     	22.526776942245796    	0                     	     0                     	                2 	0                    	0                     	 0                    	 0.3494850021680094   	                         	                                  	SN                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                          	5.114                                                                     	-                   	              	                63 	+                  	NaN                	NaN       	  86024.9 	NaN      	        12 	         2330 	          2343
20221121_F1_UM4_Peng0013_SA_EXT00_MIX3_SP3_LysN_1h 	       2345 	      11.932   	NaN                	           180570 	86.43135070800781   	         0 	            14836   	       0.499 	           	        	        	-1        	                                         	     0 	            90 	 352.68261973910853 	703.3506865450171  	     2 	 352.6827697753906  	MULTI 	ETHCD         	FTMS          	                        0 	                         0 	                 0 	2343                       	197840.28125        	0.15698731522236797     	-11                   	0.054450035095214844       	                2 	                              	                                                                                            	                                                                                                                                  	NaN                    	NaN                     	sp3_lysn_1h 	                 	             	                  	DSV                                                                                                                                                                                    	3         	-1                          	                                                                           	            	            	   15.689    	0                  	0                        	          2.2306    	           0      	            0     	0                  	399.20270715885005 	399.20270715885005 	3.9230692813577335    	0                     	0                     	     0                     	                0 	0                    	0                     	 0                    	 0                    	                         	                                  	DSV                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                         	2.2306                                                                    	-                   	              	                21 	+                  	NaN                	NaN       	  72734.8 	NaN      	        13 	         2330 	          2343
20221121_F1_UM4_Peng0013_SA_EXT00_MIX3_SP3_LysN_1h 	       2354 	      11.976   	NaN                	           230800 	35                  	         0 	            34957   	       0.346 	           	        	        	-1        	                                         	     0 	            85 	 360.1735374993197  	718.3325220654394  	     2 	 360.17376708984375 	MULTI 	CID           	FTMS          	                        0 	                         0 	                 0 	2353                       	680385.5            	0.11367031631227191     	-3                    	0.0146484375               	                1 	                              	                                                                                            	                                                                                                                                  	NaN                    	NaN                     	sp3_lysn_1h 	                 	             	                  	K                                                                                                                                                                                      	1         	-1                          	                                                                           	            	            	   37.619    	0                  	0                        	          5.237     	           0      	            0     	572.2272344451254  	0                  	572.2272344451254  	0                     	7.530586141042534     	0                     	     0                     	                2 	0.3494850021680094   	0                     	 0                    	 0.21346799108044048  	                         	                                  	K                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           	5.237                                                                     	-                   	              	               160 	+                  	NaN                	NaN       	  83612.4 	NaN      	        14 	         2338 	          2353
20221121_F1_UM4_Peng0013_SA_EXT00_MIX3_SP3_LysN_1h 	       2355 	      11.982   	NaN                	           255290 	86.43135070800781   	         0 	            25698   	       0.499 	           	        	        	-1        	                                         	     0 	            86 	 360.1735374993197  	718.3325220654394  	     2 	 360.17376708984375 	MULTI 	ETHCD         	FTMS          	                        0 	                         0 	                 0 	2353                       	680385.5            	0.11367031631227191     	-3                    	0.0146484375               	                2 	                              	                                                                                            	                                                                                                                                  	NaN                    	NaN                     	sp3_lysn_1h 	                 	             	                  	K                                                                                                                                                                                      	1         	-1                          	                                                                           	            	            	   29.208    	0                  	0                        	          4.0661    	           0      	            0     	572.2261968474692  	0                  	572.2261968474692  	0                     	5.299710790719445     	0                     	     0                     	                2 	0                    	0                     	 0                    	 0                    	                         	                                  	K                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           	4.0661                                                                    	-                   	              	                39 	+                  	NaN                	NaN       	  94582.2 	NaN      	        15 	         2338 	          2353
20221121_F1_UM4_Peng0013_SA_EXT00_MIX3_SP3_LysN_1h 	       2358 	      11.997   	NaN                	           839630 	35                  	         0 	            68756   	       0.346 	           	        	        	-1        	                                         	     0 	           202 	 364.5184437217449  	1090.5335017654347 	     3 	 364.51898193359375 	MULTI 	CID           	FTMS          	                        0 	                         0 	                 0 	2357                       	846420.375          	0.04209900124712305     	-1                    	0.005328178405761719       	                1 	                              	                                                                                            	                                                                                                                                  	NaN                    	NaN                     	sp3_lysn_1h 	                 	             	                  	P{[ET]|[MV]}{M(Oxidation (M))|F}N                                                                                                                                                      	5         	-1                          	                                                                           	            	            	   40.225    	0                  	0                        	          3.6886    	           0      	            0     	484.30283054661885 	0                  	484.30283054661885 	0                     	4.7407696121679805    	0                     	     0                     	                2 	1.0189301784845295   	0                     	 0.3494850021680094   	 0                    	                         	                                  	P{[ET]|[MV]}{M(Oxidation (M))|F}N                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                           	3.6886                                                                    	-                   	              	              1138 	+                  	NaN                	NaN       	 241587.2 	NaN      	        16 	         2340 	          2357
20221121_F1_UM4_Peng0013_SA_EXT00_MIX3_SP3_LysN_1h 	       2359 	      12.003   	NaN                	          1809400 	38.41393280029297   	         0 	            97234   	       0.451 	           	        	        	-1        	                                         	     0 	           157 	 364.5184437217449  	1090.5335017654347 	     3 	 364.51898193359375 	MULTI 	ETHCD         	FTMS          	                        0 	                         0 	                 0 	2357                       	846420.375          	0.04209900124712305     	-1                    	0.005328178405761719       	                2 	                              	                                                                                            	                                                                                                                                  	NaN                    	NaN                     	sp3_lysn_1h 	                 	             	                  	KKVEPKSCD                                                                                                                                                                              	9         	-1                          	                                                                           	            	+           	   45.635    	0                  	0                        	          4.1847    	           4.1847 	           92.641 	0                  	0                  	0                  	0.8303360952406962    	3.0102999566398125    	0.8303360952406962    	     3.0102999566398125    	                2 	1.6622367467574017   	0                     	 0.2302046884880938   	 0                    	                         	                                  	KKVEPKSCD;KKVEPKSDC;[VS]K{[VA]|[{L|I}G]}PKSCD;[VS]K{[VA]|[{L|I}G]}PKSDC;KKVEPKS[CD];KKVE{[QG]|[NA]}C{[QN]|[E{L|I}]|[KN]}                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    	4.1847;3.9087;1.8956;1.6196;1.3996;1.0014                                 	-;-;-;-;-;-         	              	              1105 	+                  	NaN                	NaN       	 482125.9 	NaN      	        17 	         2340 	          2357
20221121_F1_UM4_Peng0013_SA_EXT00_MIX3_SP3_LysN_1h 	       2360 	      12.01    	NaN                	          5302500 	35                  	         0 	           856390   	       0.343 	           	        	        	-1        	                                         	     0 	           217 	 482.2263171798785  	962.438081426557   	     2 	 482.22735595703125 	MULTI 	CID           	FTMS          	                        0 	                         0 	                 0 	2357                       	1782684.375         	0.03033970926655378     	-1                    	0.005328178405761719       	                3 	                              	                                                                                            	                                                                                                                                  	NaN                    	NaN                     	sp3_lysn_1h 	                 	             	                  	KVEPKSCD                                                                                                                                                                               	8         	-1                          	                                                                           	            	+           	  114.3      	0                  	0                        	         11.876     	          11.876  	           98.747 	0                  	0                  	0                  	19.87283262043249     	12.653262676180148    	12.653262676180148    	     7.875344171398339     	                2 	2.8001648626366045   	0.769551078621726     	 1.7530834337684316   	 0                    	                         	                                  	KVEPKSCD;KD{L|I}PKSCD;KVEPKSDC;KD{L|I}PKSDC;DK{L|I}PKSCD;{[QV]|[N{L|I}]|[RA]|[KV]}EPKSCD;{NN|[MP]|[D{L|I}]|[EV]}KPKSCD;DK{L|I}PKSDC;{[EN]|[QD]|[WG]|[KD]|[RS]}{L|I}PKSCD;{[QV]|[N{L|I}]|[RA]|[KV]}EPSKCD                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                                    	11.876;11.058;10.561;9.743;9.6231;8.6085;8.3789;8.3084;7.926;7.8546       	-;-;-;-;-;-;-;-;-;- 	              	              3138 	+                  	NaN                	NaN       	1362959   	NaN      	        18 	         2340 	          2357";

const MAXQUANT_NOVO_MSMS_SCANS_NEW: &str = "Raw file	Scan number	Retention time	Ion injection time	Total ion current	Collision energy	Summations	Base peak intensity	Elapsed time	Identified	Matched	Reverse	MS/MS IDs	Sequence	Length	Filtered peaks	m/z	Mass	Charge	MS2 m/z	Type	Fragmentation	Mass analyzer	Parent intensity fraction	Fraction of total spectrum	Base peak fraction	Precursor full scan number	Precursor intensity	Precursor apex fraction	Precursor apex offset	Precursor apex offset time	Scan event number	Modifications	Modified sequence	Proteins	Score	PEP	MS3 scan numbers	Reporter PIF	Reporter fraction	DN sequence	DN length	DN min levenshtein distance	DN extension sequence	DN extended	DN complete	DN raw score	DN extension score	DN extension norm. score	DN normalized score	DN complete score	DN combined score	DN nterm mass	DN cterm mass	DN missing mass	DN nterm delta score	DN cterm delta score	DN term delta score	DN full length delta score	DN protease score	DN complement score	DN A2 score	DN water loss score	DN ammonia loss score	DN agrees with andromeda	DN agrees with andromeda complete	DN all sequences	DN all scores	DN all agrees	DN any agrees	DN number of steps	DN is dominantly y	Intens Comp Factor	CTCD Comp	RawOvFtT	AGC Fill	Scan index	MS scan index	MS scan number
Peng2021_Herceptin_tryp	1082	5.5518	NaN	85826	150	0	9484.6	0.563				-1	ADPQCPQPATR	11	53	414.8530882002953	NaN	0	414.85345458984375	PEAK	ETHCD	FTMS	0	0	0	1081	39746.4609375	0.15245426474242343	1	-0.01165151596069336	1	2 Deamidation (NQ)	_ADPQ(Deamidation (NQ))CPQ(Deamidation (NQ))PATR_	CON__Q2UVX4	0	2.494881019055721E+68					-1	-1				0	0	0	0	0	0	NaN	NaN	NaN	0	0	0	0	0	0	0	0	0				0	-		0		NaN	NaN	44672.9	NaN	0	1080	1081
Peng2021_Herceptin_tryp	2873	14.911	NaN	911790	150	0	152240	0.563				-1		0	119	635.7412429518962	1269.4679329705923	2	635.741455078125	MULTI	ETHCD	FTMS	0	0	0	2872	774866.1875	0.7452108926331117	-1	0.0049343109130859375	1				NaN	NaN				{M(Oxidation (M))|F}{I|L}R	3	-1				34.481	0	0	2.7161	0	0	835.2041037417856	0	835.2041037417856	0	2.8165482042847323	0	0	2	0	0	0	0			{M(Oxidation (M))|F}{I|L}R	2.7161	-		256	+	NaN	NaN	248436.8	NaN	1	2870	2872
Peng2021_Herceptin_tryp	2875	14.922	NaN	500140	150	0	53154	0.564				-1		0	91	476.197299664117	475.190023197517	1	476.19769287109375	MULTI	ETHCD	FTMS	0	0	0	2874	472027.5625	0.9825358978034996	-92	0.47070789337158203	1				NaN	NaN				{M(Oxidation (M))|F}	1	-1				3.7176	0	0	0.78234	0	0	107.07632653484377	218.05457483463127	325.13090136947505	0	0	0	0	0	0	0	0	0			{M(Oxidation (M))|F}	0.78234	-		5	+	NaN	NaN	146767.3	NaN	2	2871	2874
Peng2021_Herceptin_tryp	2876	14.931	NaN	515210	35	0	53440	0.363				-1		0	137	385.7239223004127	769.4332916676254	2	385.7241516113281	MULTI	CID	FTMS	0	0	0	2874	902110.9375	1	0	0	2				NaN	NaN				{I|L}PVKQA{D|N(Deamidation (NQ))}	7	-1			+	68.358	0	0	8.8842	8.8842	97.579	0	0	0	37.90195407729474	7.793314231173241	7.793314231173241	9.34574383489921	2	0.1861818737241735	0.958607314841775	0.3494850021680094	0			{I|L}PVKQA{D|N(Deamidation (NQ))};{I|L}PVK[AG]A{D|N(Deamidation (NQ))}	8.8842;7.6695	-;-		194	+	NaN	NaN	150206.4	NaN	3	2871	2874
Peng2021_Herceptin_tryp	2877	14.936	NaN	122580	35	0	14971	0.363				-1		0	51	713.7921243299916	1425.569695726783	2	713.792236328125	MULTI	CID	FTMS	0	0	0	2874	315317.03125	1	0	0	3				NaN	NaN				R	1	-1				35.707	0	0	2.5048	0	0	1251.4578773447502	0	1251.4578773447502	0	21.505149978319906	0	0	2	0	0	0	0			R	2.5048	-		4	+	NaN	NaN	51436.4	NaN	4	2871	2874
Peng2021_Herceptin_tryp	2878	14.941	NaN	143910	35	0	7719.3	0.364				-1	CQYEALVETNRR	12	95	770.8546395201536	1539.694726107107	2	770.8555908203125	MULTI	CID	FTMS	0	0	0	2874	348111.6875	1	0	0	4	2 Deamidation (NQ)	_CQ(Deamidation (NQ))YEALVETN(Deamidation (NQ))RR_	CON__Q9D646;CON__REFSEQ:XP_986630	0	222.79836514070942				T[{I|L}P][{D|N(Deamidation (NQ))}G]G[VP]	8	-1				35.65	0	0	2.3154	0	0	785.3093128888687	0	785.3093128888687	0	21.80971986198139	0	0	0	1.9247425010840047	0	0.805462187404089	0			T[{I|L}P][{D|N(Deamidation (NQ))}G]G[VP]	2.3154	-		91		NaN	NaN	63043.1	NaN	5	2871	2874
Peng2021_Herceptin_tryp	2880	14.949	NaN	26598	85.99577331542969	0	6568.1	0.499			+	-1	IRITSKACVRPEVLPLNVVQLVSPQVEAVSTTWTR	35	24	1975.57421875	NaN	0	1975.57421875	PEAK	ETHCD	FTMS	0	0	0	-1	NaN	NaN	0	NaN	1	3 Deamidation (NQ)	_IRITSKACVRPEVLPLN(Deamidation (NQ))VVQ(Deamidation (NQ))LVSPQ(Deamidation (NQ))VEAVSTTWTR_	REV__CON__P00735	5.931240732196476E-11	0.01751154576626646					-1	-1				0	0	0	0	0	0	NaN	NaN	NaN	0	0	0	0	0	0	0	0	0				0	-		0		NaN	NaN	25960.4	NaN	6	2872	2879
Peng2021_Herceptin_tryp	2881	14.957	NaN	195680	35	0	19992	0.364				-1	ALEEANADLEQKIKGWYEK	19	63	559.5378236964274	2234.1221889193093	4	559.7886962890625	MULTI	CID	FTMS	0	0	0	2879	163004.4375	0.15342287228034773	1	-0.05119895935058594	2	Unmodified	_ALEEANADLEQKIKGWYEK_	CON__Q7Z3Y8	0	2.4239560307942454				[{I|L}T]{M(Oxidation (M))|F}SQ	5	-1				43.094	0	0	1.9289	0	0	0	1654.7650943867413	1654.7650943867413	25.514814611342157	0	0	0	0	0	2	0	0			[{I|L}T]{M(Oxidation (M))|F}SQ	1.9289	-		36	+	NaN	NaN	69381.5	NaN	7	2872	2879
Peng2021_Herceptin_tryp	2882	14.962	NaN	145940	35	0	25318	0.365				-1	NLDLDSIIAEVRAQYEDIALK	21	59	598.5628801870694	2390.2224148818773	4	598.8134155273438	MULTI	CID	FTMS	0	0	0	2879	123938.2734375	0.13338058516784862	1	-0.05119895935058594	3	2 Deamidation (NQ)	_N(Deamidation (NQ))LDLDSIIAEVRAQ(Deamidation (NQ))YEDIALK_	CON__Q6NXH9	0	0.0613598952576724				{M(Oxidation (M))|F}{E|Q(Deamidation (NQ))}	2	-1				16.643	0	0	0.69631	0	0	2096.101609073087	0	2096.101609073087	0	9.430951486635273	0	0	0	0	0	0	0			{M(Oxidation (M))|F}{E|Q(Deamidation (NQ))}	0.69631	-		13	+	NaN	NaN	58223.9	NaN	8	2872	2879
Peng2021_Herceptin_tryp	2883	14.967	NaN	293790	35	0	15839	0.364				-1		0	62	619.3612849829854	2473.416034065541	4	619.6121215820312	MULTI	CID	FTMS	0	0	0	2879	401258.84375	0.22337311931459225	1	-0.05119895935058594	4				NaN	NaN				{E|Q(Deamidation (NQ))}N{I|L}Y{M(Oxidation (M))|F}[QA]	7	-1				44.553	0	0	1.8013	0	0	1590.0114580080747	0	1590.0114580080747	0	36.6752380872608	0	0	0	0.8494850021680094	0	0	0			{E|Q(Deamidation (NQ))}N{I|L}Y{M(Oxidation (M))|F}[QA]	1.8013	-		47		NaN	NaN	96990.4	NaN	9	2872	2879
Peng2021_Herceptin_tryp	2884	14.972	NaN	885860	35	0	129600	0.363				-1		0	73	702.2101986065297	701.2029221399297	1	702.0800170898438	MULTI	CID	FTMS	0	0	0	2879	520205.1875	0.7650040427200203	-1	0.02707195281982422	5				NaN	NaN				{M(Oxidation (M))|F}	1	-1				2.697	0	0	0.38463	0	0	331.1098774776515	220.03415857486564	551.1440360525171	0	0	0	0	0	0	0	0	0			{M(Oxidation (M))|F}	0.38463	-		12	+	NaN	NaN	240591.2	NaN	10	2872	2879
Peng2021_Herceptin_tryp	2885	14.977	NaN	94791	35	0	9764.6	0.364				-1		0	59	399.56669233182566	1195.678247595677	3	399.5661315917969	MULTI	CID	FTMS	0	0	0	2879	68629.03125	0.28076933181783054	1	-0.05119895935058594	6				NaN	NaN				P	1	-1				7.2125	0	0	0.60321	0	0	897.5235367575896	198.07734094791252	1095.6008777055022	0	0	0	0	0	0	0	0	0			P	0.60321	-		10	+	NaN	NaN	56134.6	NaN	11	2872	2879
Peng2021_Herceptin_tryp	2886	14.982	NaN	104310	35	0	10018	0.363				-1	FKDLGEEHFK	10	66	417.21214033297633	NaN	0	417.2120361328125	PEAK	CID	FTMS	0	0	0	2879	54217.37890625	0.24696645285141725	1	-0.05119895935058594	7	Unmodified	_FKDLGEEHFK_	CON__P02769	1.0714618166137932	0.015633357781438848				AV	2	-1				8.4043	0	0	1.0096	0	0	105.97095927747769	553.3114107721311	659.2823700496089	0	0	0	0	0	0	0	0	0			AV	1.0096	-		8	+	NaN	NaN	46021.7	NaN	12	2872	2879
Peng2021_Herceptin_tryp	2887	14.987	NaN	57924	35	0	7120.1	0.364				-1	EVALNTIIFMGR	12	48	455.5797286704695	NaN	0	455.24578857421875	PEAK	CID	FTMS	0	0	0	2879	37389.453125	0.11996296422184209	1	-0.05119895935058594	8	Deamidation (NQ)	_EVALN(Deamidation (NQ))TIIFMGR_	CON__P41361	0	0.014232564426154152				KV	2	-1				4.5136	0	0	0.49646	0	0	325.7993366360577	353.15754114322505	678.9568777792828	0	0	0	0	0	0	0	0	0			KV	0.49646	-		5	+	NaN	NaN	38326.9	NaN	13	2872	2879
Peng2021_Herceptin_tryp	2888	14.992	NaN	91039	35	0	6967.9	0.365				-1	LKECCDKPLLEK	12	67	511.59860797019223	1531.7739945107767	3	511.598388671875	MULTI	CID	FTMS	0	0	0	2879	82524.96875	0.2697855955605092	1	-0.05119895935058594	9	Unmodified	_LKECCDKPLLEK_	CON__P02769	0.056626984729814075	222.79836514070942				H	1	-1				2.4413	0	0	0.15937	0	0	1193.615591045736	198.07785974674064	1391.6934507924766	0	0	0	0	0	0	0	0	0			H	0.15937	-		4	+	NaN	NaN	44991.6	NaN	14	2872	2879
Peng2021_Herceptin_tryp	2890	15.001	NaN	60557	150	0	6034.2	0.563				-1	LQGEIAHVK	9	43	497.78917607319585	NaN	0	497.789306640625	PEAK	ETHCD	FTMS	0	0	0	2889	35107.14453125	0.16556744977357746	1	-0.011983871459960938	1	Unmodified	_LQGEIAHVK_	CON__P35908;CON__P35908v2	0	7.626347534228387E+63				Y	1	-1				0.70731	0	0	0.07119	0	0	503.3370363731511	324.13215051822505	827.4691868913761	0	0	0	0	0	0	0	0	0			Y	0.07119	-		1	+	NaN	NaN	39534.9	NaN	15	2873	2889
Peng2021_Herceptin_tryp	2892	15.013	NaN	272060	150	0	10832	0.563				-1		0	85	1026.4445385508618	3076.3117862527856	3	1027.1146240234375	MULTI	ETHCD	FTMS	0	0	0	2891	345832.96875	0.2821288695332418	3	-0.022924423217773438	1				NaN	NaN				{D|N(Deamidation (NQ))}A	2	-1				15.662	0	0	0.50912	0	0	2307.8609328365733	579.3620699518186	2887.223002788392	0	0	0	0	0	0	0	0	0.4247425010840047			{D|N(Deamidation (NQ))}A	0.50912	-		28	+	NaN	NaN	89243.9	NaN	16	2874	2891
Peng2021_Herceptin_tryp	3223	16.722	NaN	17198000	150	0	1491600	0.564				-1		0	197	382.2204605038279	1143.6395521116838	3	382.2206115722656	MULTI	ETHCD	FTMS	0	0	0	3222	190723056	0.41476852216237636	-1	0.0050983428955078125	1				NaN	NaN				YQQKPGKAPK	10	-1			+	113.26	0	0	9.9039	9.9039	98.033	0	0	0	40.86721247813779	20.036134084268156	20.036134084268156	9.179751216704588	2	2.486346736360778	1.0457574905606752	0	1.4604093769761874			YQQKPGKAPK;YQ[AG]KPGKAPK;YQQKP[KQ]PK;YQQKK[PG]APK;YQQKK[QP]PK;Y[AG]QKPGKAPK;YQ[AG]KP[KQ]PK;YQQK[{I|L}V][HT]K;YQ[AG]KK[PG]APK;YQQKPGKK[PA]	9.9039;9.1012;8.8051;8.7154;8.2748;8.1868;7.9986;7.9645;7.9127;7.904	-;-;-;-;-;-;-;-;-;-		20178	+	NaN	NaN	4338578	NaN	17	3204	3222
Peng2021_Herceptin_tryp	3224	16.731	NaN	13449000	35	0	807970	0.363				-1	ALVFVDNHDNQR	12	501	476.90101572458514	1427.6812177739555	3	476.90185546875	MULTI	CID	FTMS	0	0	0	3222	7877181.5	0.32541819426270824	-1	0.0050983428955078125	2	Deamidation (NQ)	_ALVFVDNHDN(Deamidation (NQ))QR_	CON__Q3MHH8	0.26538908928332583	23.155714642610686				{I|L}{D|N(Deamidation (NQ))}NVNHKPSNTK	12	-1				146.43	0	0	10.256	0	0	61.99602626060216	0	61.99602626060216	0	80.95983742624236	0	0	2	0	0	2.2376954943324545	3.05902924611682			{I|L}{D|N(Deamidation (NQ))}NVNHKPSNTK	10.256	-		167870	+	NaN	NaN	3435191	NaN	18	3204	3222";

const MAXQUANT_SILAC: &str = "Sequence	Length	K Count	R Count	Modifications	Modified sequence	Carbamidomethyl (C) Probabilities	NEM Probabilities	Oxidation (M) Probabilities	Carbamidomethyl (C) Score Diffs	NEM Score Diffs	Oxidation (M) Score Diffs	Acetyl (Protein N-term)	Carbamidomethyl (C)	NEM	Oxidation (M)	Missed cleavages	Proteins	Leading proteins	Leading razor protein	Gene names	Protein names	Type	Labeling State	Raw file	Experiment	MS/MS m/z	Charge	m/z	Mass	Uncalibrated - Calibrated m/z [ppm]	Uncalibrated - Calibrated m/z [Da]	Mass error [ppm]	Mass error [Da]	Uncalibrated mass error [ppm]	Uncalibrated mass error [Da]	Max intensity m/z 0	Max intensity m/z 1	Retention time	Retention length	Calibrated retention time	Calibrated retention time start	Calibrated retention time finish	Retention time calibration	Match time difference	Match m/z difference	Match q-value	Match score	Number of data points	Number of scans	Number of isotopic peaks	PIF	Fraction of total spectrum	Base peak fraction	PEP	MS/MS count	MS/MS scan number	MS/MS scan numbers	MS3 scan numbers	Score	Delta score	Combinatorics	Ratio H/L	Ratio H/L normalized	Ratio H/L shift	Intensity	Intensity L	Intensity H	Reverse	Potential contaminant	id	Protein group IDs	Peptide ID	Mod. peptide ID	MS/MS IDs	Best MS/MS	Carbamidomethyl (C) site IDs	NEM site IDs	Oxidation (M) site IDs	Taxonomy IDs	Taxonomy names	Mass deficit	Theor. isotope correlation	Isotope correlation	Time correlation
AAAAAAVGPGAGGAGSAVPGGAGPCATVSVFPGAR	35	0	1	Acetyl (Protein N-term),Carbamidomethyl (C)	_(Acetyl (Protein N-term))AAAAAAVGPGAGGAGSAVPGGAGPC(Carbamidomethyl (C))ATVSVFPGAR_	AAAAAAVGPGAGGAGSAVPGGAGPC(1)ATVSVFPGAR			AAAAAAVGPGAGGAGSAVPGGAGPC(52)ATVSVFPGAR			1	1	0	0	0	Q86X55	Q86X55	Q86X55	CARM1	Histone-arginine methyltransferase CARM1	ISO-MSMS	0	20240503_EX1_UM3_Neder016_SA_EXT00_ssABE_LPS_2H	2H	984.4912109375	3	983.826039	2948.45629	NaN	NaN	-1.1278	-0.0011095	NaN	NaN	NaN	NaN	37.209	0.15495	37.246	37.137	37.292	0.037453								0	0	0	1.252E-05	1	42275	42275		51.9	40.645	1	1.2986	1.1129	0	41203000	30702000	10501000			0	1723	0	0	0	0	4677					0.0599979585881556			
AAAAAAVGPGAGGAGSAVPGGAGPCATVSVFPGAR	35	0	1	Acetyl (Protein N-term),Carbamidomethyl (C)	_(Acetyl (Protein N-term))AAAAAAVGPGAGGAGSAVPGGAGPC(Carbamidomethyl (C))ATVSVFPGAR_	AAAAAAVGPGAGGAGSAVPGGAGPC(1)ATVSVFPGAR			AAAAAAVGPGAGGAGSAVPGGAGPC(46)ATVSVFPGAR			1	1	0	0	0	Q86X55	Q86X55	Q86X55	CARM1	Histone-arginine methyltransferase CARM1	ISO-MSMS	0	20240503_EX1_UM3_Neder016_SA_EXT00_ssABE_LPS_3L	3L	983.826904296875	3	983.826039	2948.45629	NaN	NaN	-0.043596	-4.2891E-05	NaN	NaN	NaN	NaN	37.18	0.16776	37.187	37.086	37.254	0.00774								0	0	0	0.0010182	2	41582	41509;41582		46.149	38.652	1	0.63379	0.71963	0	33916000	31452000	2463500			1	1723	0	0	1;2	2	4677					0.0599979585881556			
AAAAECDVVMAATEPELLDDQEAK	24	1	0	Acetyl (Protein N-term),Carbamidomethyl (C)	_(Acetyl (Protein N-term))AAAAEC(Carbamidomethyl (C))DVVMAATEPELLDDQEAK_	AAAAEC(1)DVVMAATEPELLDDQEAK			AAAAEC(150)DVVMAATEPELLDDQEAK			1	1	0	0	0	Q99615	Q99615	Q99615	DNAJC7	DnaJ homolog subfamily C member 7	MULTI-MSMS		20240503_EX1_UM3_Neder016_SA_EXT00_ssABE_LPS_1H	1H	864.3967895507812	3	863.728009	2588.1622	-0.63499	-0.00054846	-0.18674	-0.00016129	-0.82173	-0.00070975	864.397299440235	866.3973555350774	43.135	0.25949	43.135	43	43.26	0					423	47	14	0	0	0	4.3535000000000003E-29	4	49980	49820;49822;49980;49994		146.6	146.6	1	0.81248	0.84241	0	895110000	413870000	481240000			2	2091	1	1	3;4;5;6	5	5431					-0.06835578745904058	0.9792858	0.95722574	0.98833406
AAAAECDVVMAATEPELLDDQEAK	24	1	0	Acetyl (Protein N-term),Carbamidomethyl (C)	_(Acetyl (Protein N-term))AAAAEC(Carbamidomethyl (C))DVVMAATEPELLDDQEAK_	AAAAEC(1)DVVMAATEPELLDDQEAK			AAAAEC(120)DVVMAATEPELLDDQEAK			1	1	0	0	0	Q99615	Q99615	Q99615	DNAJC7	DnaJ homolog subfamily C member 7	MSMS	1	20240503_EX1_UM3_Neder016_SA_EXT00_ssABE_LPS_2H	2H	1299.096069335938	2	1295.08838	2588.1622	NaN	NaN	NaN	NaN	NaN	NaN	NaN	NaN	43.124	1	43.167	42.667	43.667	0.042629								0	0	0	4.9809E-17	1	50477	50477		115.82	87.183	1									3	2091	1	1	7	7	5431					-0.06835578745904058			
AAAAECDVVMAATEPELLDDQEAK	24	1	0	Acetyl (Protein N-term),Carbamidomethyl (C)	_(Acetyl (Protein N-term))AAAAEC(Carbamidomethyl (C))DVVMAATEPELLDDQEAK_	AAAAEC(1)DVVMAATEPELLDDQEAK			AAAAEC(110)DVVMAATEPELLDDQEAK			1	1	0	0	0	Q99615	Q99615	Q99615	DNAJC7	DnaJ homolog subfamily C member 7	MULTI-MSMS		20240503_EX1_UM3_Neder016_SA_EXT00_ssABE_LPS_3L	3L	867.7368774414062	3	863.728009	2588.1622	0.13009	0.00011237	-0.39152	-0.00033816	-0.26142	-0.0002258	864.0623859572274	866.7337122073088	43.101	0.26624	43.109	42.98	43.247	0.0075607					390	49	11	0	0	0	9.3911E-14	4	49348	49258;49276;49348;49452		105.79	97.604	1	0.49863	0.6219	0	870080000	548230000	321850000			4	2091	1	1	8;9;10;11	10	5431					-0.06835578745904058	0.99756473	0.9775378	0.98704356
AAAAECDVVMAATEPELLDDQEAK	24	1	0	Acetyl (Protein N-term),Carbamidomethyl (C)	_(Acetyl (Protein N-term))AAAAEC(Carbamidomethyl (C))DVVMAATEPELLDDQEAK_	AAAAEC(1)DVVMAATEPELLDDQEAK			AAAAEC(120)DVVMAATEPELLDDQEAK			1	1	0	0	0	Q99615	Q99615	Q99615	DNAJC7	DnaJ homolog subfamily C member 7	MULTI-MSMS		20240503_EX1_UM3_Neder016_SA_EXT00_ssABE_LPS_4L	4L	866.397705078125	3	863.728009	2588.1622	0.057747	4.9878E-05	-0.24842	-0.00021456	-0.19067	-0.00016469	864.0627464556183	866.7336471749006	43.129	0.2677	43.1	42.971	43.239	-0.028801					449	49	14	0	0	0	2.6339E-17	3	50035	49997;50035;50218		116.35	112.38	1	0.53194	0.64098	0	892660000	520170000	372490000			5	2091	1	1	12;13;14	13	5431					-0.06835578745904058	0.9840865	0.93412495	0.98507833
AAAAECDVVMAATEPELLDDQEAK	24	1	0	Acetyl (Protein N-term),Carbamidomethyl (C)	_(Acetyl (Protein N-term))AAAAEC(Carbamidomethyl (C))DVVMAATEPELLDDQEAK_							1	1	0	0	0	Q99615	Q99615	Q99615	DNAJC7	DnaJ homolog subfamily C member 7	MULTI-MATCH-MSMS		20240503_EX1_UM3_Neder016_SA_EXT00_ssABE_LPS_2H	2H		3	863.728009	2588.1622	0.15049	0.00012998	0.88914	0.00076797	1.0396	0.00089795	864.0635036872925	867.0667820019896	43.121	0.40585	43.164	42.882	43.288	0.042629	0.036876	0.0028739	NaN	146.6	111	19	10	NaN	NaN	NaN	NaN	0				NaN	NaN	0	0.97454	0.75162	0	396910000	167520000	229390000			6	2091	1	1			5431					-0.06835578745904058	0.9052026	0.7470819	0.98216444
AAAGELQEDSGLCVLAR	17	0	1	Carbamidomethyl (C)	_AAAGELQEDSGLC(Carbamidomethyl (C))VLAR_	AAAGELQEDSGLC(1)VLAR			AAAGELQEDSGLC(120)VLAR			0	1	0	0	0	Q96C19	Q96C19	Q96C19	EFHD2	EF-hand domain-containing protein D2	ISO-MSMS	1	20240503_EX1_UM3_Neder016_SA_EXT00_ssABE_LPS_1H	1H	885.9425659179688	2	880.4358	1758.85705	NaN	NaN	1.216	0.0010706	NaN	NaN	NaN	NaN	31.062	0.13632	31.062	30.986	31.122	0								0	0	0	3.3709E-08	1	33563	33563		124.38	105.63	1	1.1028	1.0798	0	59546000	10308000	49238000			7	1976	2	2	15	15	5196					0.007973275442054728			
AAAGELQEDSGLCVLAR	17	0	1	Carbamidomethyl (C)	_AAAGELQEDSGLC(Carbamidomethyl (C))VLAR_	AAAGELQEDSGLC(1)VLAR			AAAGELQEDSGLC(150)VLAR			0	1	0	0	0	Q96C19	Q96C19	Q96C19	EFHD2	EF-hand domain-containing protein D2	ISO-MSMS	0	20240503_EX1_UM3_Neder016_SA_EXT00_ssABE_LPS_1H	1H	880.4378662109375	2	880.4358	1758.85705	NaN	NaN	2.3824	0.0020976	NaN	NaN	NaN	NaN	31.062	0.15343	31.062	30.986	31.139	0								0	0	0	4.1384E-18	1	33568	33568		153.63	120.22	1	1.0504	1.0282	0	58578000	49118000	9459400			8	1976	2	2	16	16	5196					0.007973275442054728			
AAAGELQEDSGLCVLAR	17	0	1	Carbamidomethyl (C)	_AAAGELQEDSGLC(Carbamidomethyl (C))VLAR_	AAAGELQEDSGLC(1)VLAR			AAAGELQEDSGLC(190)VLAR			0	1	0	0	0	Q96C19	Q96C19	Q96C19	EFHD2	EF-hand domain-containing protein D2	ISO-MSMS	0	20240503_EX1_UM3_Neder016_SA_EXT00_ssABE_LPS_2H	2H	880.93701171875	2	880.4358	1758.85705	NaN	NaN	1.4704	0.0012946	NaN	NaN	NaN	NaN	31.025	0.20426	31.056	30.941	31.145	0.030951								0	0	0	9.9727E-34	1	33667	33667		193.23	149.93	1	1.2284	0.94823	0	222380000	182080000	40299000			9	1976	2	2	17	17	5196					0.007973275442054728			
AAAGELQEDSGLCVLAR	17	0	1	Carbamidomethyl (C)	_AAAGELQEDSGLC(Carbamidomethyl (C))VLAR_	AAAGELQEDSGLC(1)VLAR			AAAGELQEDSGLC(160)VLAR			0	1	0	0	0	Q96C19	Q96C19	Q96C19	EFHD2	EF-hand domain-containing protein D2	MULTI-MSMS		20240503_EX1_UM3_Neder016_SA_EXT00_ssABE_LPS_3L	3L	880.4379272460938	2	880.4358	1758.85705	-0.55893	-0.0004921	1.2957	0.0011408	0.73678	0.00064869	880.4377886211744	885.4394837697027	31.019	0.15361	31.025	30.949	31.102	0.0064545					38	8	6	0	0	0	3.6393E-21	2	33076	33076;33109		158.42	142.16	1	0.45146	0.53669	0	101040000	68420000	32617000			10	1976	2	2	18;19	18	5196					0.007973275442054728	0.9860144	0.9626761	0.9672731
AAAGELQEDSGLCVLAR	17	0	1	Carbamidomethyl (C)	_AAAGELQEDSGLC(Carbamidomethyl (C))VLAR_	AAAGELQEDSGLC(1)VLAR			AAAGELQEDSGLC(160)VLAR			0	1	0	0	0	Q96C19	Q96C19	Q96C19	EFHD2	EF-hand domain-containing protein D2	MULTI-MSMS		20240503_EX1_UM3_Neder016_SA_EXT00_ssABE_LPS_4L	4L	880.9375610351562	2	880.4358	1758.85705	-0.053245	-4.6879E-05	1.0659	0.00093849	1.0127	0.00089161	880.4374703295418	885.4410200265721	31.052	0.1711	31.026	30.931	31.102	-0.025961					31	9	5	0	0	0	4.1539999999999996E-22	2	33832	33832;33860		161.99	145.73	1	0.59892	0.65417	0	101190000	57855000	43335000			11	1976	2	2	20;21	20	5196					0.007973275442054728	0.9687632	0.9260208	0.92050904
AAAGGLAMLTSMRPTLCSR	19	0	2	Carbamidomethyl (C)	_AAAGGLAMLTSMRPTLC(Carbamidomethyl (C))SR_	AAAGGLAMLTSMRPTLC(1)SR			AAAGGLAMLTSMRPTLC(71)SR			0	1	0	0	0	Q9H3U1	Q9H3U1	Q9H3U1	UNC45A	Protein unc-45 homolog A	MULTI-MSMS		20240503_EX1_UM3_Neder016_SA_EXT00_ssABE_LPS_1H	1H	655.3345947265625	3	655.333995	1962.98016	0.22614	0.00014819	-0.79732	-0.00052251	-0.57118	-0.00037431	655.3348541600152	662.0062408998527	35.166	0.18781	35.166	35.057	35.245	0					30	10	5	0	0	0	4.7146E-06	1	39193	39193		70.942	61.154	1	0.76427	0.77784	0	68930000	47574000	21355000			12	2235	3	3	22	22	5724					0.03718544399453094	0.9709616	0.89091	0.73409986
AAAGGLAMLTSMRPTLCSR	19	0	2	Carbamidomethyl (C)	_AAAGGLAMLTSMRPTLC(Carbamidomethyl (C))SR_	AAAGGLAMLTSMRPTLC(1)SR			AAAGGLAMLTSMRPTLC(47)SR			0	1	0	0	0	Q9H3U1	Q9H3U1	Q9H3U1	UNC45A	Protein unc-45 homolog A	ISO-MSMS	1	20240503_EX1_UM3_Neder016_SA_EXT00_ssABE_LPS_2H	2H	662.3395385742188	3	655.333995	1962.98016	NaN	NaN	-2.0059	-0.0013146	NaN	NaN	NaN	NaN	35.115	0.13616	35.15	35.096	35.232	0.035202								0	0	0	0.0041264	2	39452	39349;39452		47.09	37.56	1	1.3823	1.2947	0	90767000	11152000	79615000			13	2235	3	3	23;24	24	5724					0.03718544399453094			
AAAGGLAMLTSMRPTLCSR	19	0	2	Carbamidomethyl (C)	_AAAGGLAMLTSMRPTLC(Carbamidomethyl (C))SR_	AAAGGLAMLTSMRPTLC(1)SR			AAAGGLAMLTSMRPTLC(62)SR			0	1	0	0	0	Q9H3U1	Q9H3U1	Q9H3U1	UNC45A	Protein unc-45 homolog A	ISO-MSMS	0	20240503_EX1_UM3_Neder016_SA_EXT00_ssABE_LPS_2H	2H	655.3341064453125	3	655.333995	1962.98016	NaN	NaN	0.087673	5.7455E-05	NaN	NaN	NaN	NaN	35.127	0.17039	35.163	35.079	35.249	0.035198								0	0	0	0.00036308	1	39386	39386		62.203	51.735	1	1.1373	1.0652	0	77364000	60786000	16578000			14	2235	3	3	25	25	5724					0.03718544399453094			
AAAGGLAMLTSMRPTLCSR	19	0	2	Carbamidomethyl (C)	_AAAGGLAMLTSMRPTLC(Carbamidomethyl (C))SR_	AAAGGLAMLTSMRPTLC(1)SR			AAAGGLAMLTSMRPTLC(54)SR			0	1	0	0	0	Q9H3U1	Q9H3U1	Q9H3U1	UNC45A	Protein unc-45 homolog A	ISO-MSMS	0	20240503_EX1_UM3_Neder016_SA_EXT00_ssABE_LPS_3L	3L	655.3347778320312	3	655.333995	1962.98016	NaN	NaN	-0.78542	-0.00051472	NaN	NaN	NaN	NaN	35.118	0.17038	35.125	35.036	35.206	0.0071106								0	0	0	0.00081684	1	38674	38674		54.288	44.092	1	0.72292	0.78508	0	50456000	44188000	6268100			15	2235	3	3	26	26	5724					0.03718544399453094			
AAAGGLAMLTSMRPTLCSR	19	0	2	Carbamidomethyl (C)	_AAAGGLAMLTSMRPTLC(Carbamidomethyl (C))SR_	AAAGGLAMLTSMRPTLC(1)SR			AAAGGLAMLTSMRPTLC(73)SR			0	1	0	0	0	Q9H3U1	Q9H3U1	Q9H3U1	UNC45A	Protein unc-45 homolog A	ISO-MSMS	0	20240503_EX1_UM3_Neder016_SA_EXT00_ssABE_LPS_4L	4L	655.3331298828125	3	655.333995	1962.98016	NaN	NaN	-0.4585	-0.00030047	NaN	NaN	NaN	NaN	35.158	0.18807	35.133	35.014	35.202	-0.02557								0	0	0	2.5876E-05	2	39443	39432;39443		72.819	56.392	1	0.76397	0.80266	0	57474000	49180000	8294500			16	2235	3	3	27;28	28	5724					0.03718544399453094			
AAALCNACELSGK	13	1	0	Carbamidomethyl (C),NEM	_AAALC(NEM)NAC(Carbamidomethyl (C))ELSGK_	AAALC(0.019)NAC(0.981)ELSGK	AAALC(0.981)NAC(0.019)ELSGK		AAALC(-17)NAC(17)ELSGK	AAALC(17)NAC(-17)ELSGK		0	1	1	0	0	Q7Z392	Q7Z392	Q7Z392	TRAPPC11	Trafficking protein particle complex subunit 11	MSMS	1	20240503_EX1_UM3_Neder016_SA_EXT00_ssABE_LPS_2H	2H	720.8419799804688	2	716.831594	1431.64863	NaN	NaN	NaN	NaN	NaN	NaN	NaN	NaN	26.89	1	26.917	26.417	27.417	0.027546								0	0	0	0.01341	1	27968	27968		51.927	38.573	2									17	1682	4	4	29	29	4579	981				-0.049923725737471614			
AAANFFSASCVPCADQSSFPK	21	1	0	Carbamidomethyl (C),NEM	_AAANFFSASC(Carbamidomethyl (C))VPC(NEM)ADQSSFPK_	AAANFFSASC(0.992)VPC(0.008)ADQSSFPK	AAANFFSASC(0.008)VPC(0.992)ADQSSFPK		AAANFFSASC(21)VPC(-21)ADQSSFPK	AAANFFSASC(-21)VPC(21)ADQSSFPK		0	1	1	0	0	CON__Q29443;CON__Q0IIK2	CON__Q29443	CON__Q29443			ISO-MSMS	0	20240503_EX1_UM3_Neder016_SA_EXT00_ssABE_LPS_4L	4L	1165.51513671875	2	1165.51445	2329.01435	NaN	NaN	0.18336	0.00021371	NaN	NaN	NaN	NaN	37.455	0.18769	37.429	37.325	37.513	-0.0256								0	0	0	0.00030365	1	42622	42622		59.306	47.866	2	NaN	NaN	0	5430200	5430200	0		+	18	49	5	5	30	30	152;153	38;39				-0.09699380698566529			";
